'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var antd = require('antd');
var React = require('react');
var React__default = _interopDefault(React);
var icons = require('@ant-design/icons');
var Draggable = _interopDefault(require('react-draggable'));
var reactColor = require('react-color');
var common = require('react-color/lib/components/common');
var dayjsGenerateConfig = _interopDefault(require('rc-picker/es/generate/dayjs'));
var generatePicker = _interopDefault(require('antd/es/date-picker/generatePicker'));
require('antd/es/date-picker/style/index');
var echarts = require('echarts');
var classNames = _interopDefault(require('classnames'));
var reactRouterDom = require('react-router-dom');
var ReactDOM = _interopDefault(require('react-dom'));
var reactDnd = require('react-dnd');
var XLSX = require('xlsx');
var Stats = _interopDefault(require('stats.js'));
var g2 = require('@antv/g2');
var axios = _interopDefault(require('axios'));
var SparkMD5 = _interopDefault(require('spark-md5'));

function PhotoPanel(props) {
  return React__default.createElement("div", {
    className: "tn-photo-panel-container"
  }, props.photos.length > 0 && React__default.createElement(antd.Carousel, {
    autoplay: true,
    key: "tn-photo-panel-carousel",
    effect: "fade"
  }, props.photos.map(function (photo) {
    return React__default.createElement("div", {
      key: photo.id
    }, React__default.createElement(antd.Image, {
      width: props.width ? props.width : 200,
      height: props.height ? props.height : 200,
      key: photo.id,
      src: photo.url,
      rootClassName: "photo-wrapper"
    }));
  })));
}

function TestDiv(props) {
  return React__default.createElement("div", {
    className: "test-div-main"
  }, props.title);
}

//hex颜色转rgb颜色
var HexStringToKeywords = {
  '#ff0000': '红',
  '#ffff00': '黄',
  '#00ff00': '绿',
  '#00ffff': '青',
  '#0000ff': '蓝',
  '#ff00ff': '洋红',
  '#ffffff': '白',
  '#808080': '深灰',
  '#c0c0c0': '浅灰'
};
var HexStringToRGB = function HexStringToRGB(value) {
  var m = /^\#([A-Fa-f\d]+)$/.exec(value);
  var hex = m[1];
  var size = hex.length;

  if (size === 3) {
    // #ff0
    var r = parseInt(hex.charAt(0) + hex.charAt(0), 16);
    var g = parseInt(hex.charAt(1) + hex.charAt(1), 16);
    var b = parseInt(hex.charAt(2) + hex.charAt(2), 16);
    return {
      r: r,
      g: g,
      b: b,
      a: 1.0
    };
  } else if (size === 6) {
    // #ff0000
    var _r3 = parseInt(hex.charAt(0) + hex.charAt(1), 16);

    var _g3 = parseInt(hex.charAt(2) + hex.charAt(3), 16);

    var _b3 = parseInt(hex.charAt(4) + hex.charAt(5), 16);

    return {
      r: _r3,
      g: _g3,
      b: _b3,
      a: 1.0
    };
  } else {
    var _r4 = -1;

    var _g4 = -1;

    var _b4 = -1;

    return {
      r: _r4,
      g: _g4,
      b: _b4,
      a: 1.0
    };
  }
};
var RGBToHex = function RGBToHex(value) {
  return value.r << 16 ^ value.g << 8 ^ value.b << 0;
};
var RGBToHexString = function RGBToHexString(value) {
  var res = ('000000' + RGBToHex(value).toString(16)).slice(-6);
  return "#" + res;
};
var HSVToRGB = function HSVToRGB(value) {
  var h = value.h,
      s = value.s,
      v = value.v; // s = s / 100;
  // v = v / 100;

  var r = 0,
      g = 0,
      b = 0;
  var i = Math.floor(h / 60 % 6);
  var f = h / 60 - i;
  var p = v * (1 - s);
  var q = v * (1 - f * s);
  var t = v * (1 - (1 - f) * s);

  switch (i) {
    case 0:
      r = v;
      g = t;
      b = p;
      break;

    case 1:
      r = q;
      g = v;
      b = p;
      break;

    case 2:
      r = p;
      g = v;
      b = t;
      break;

    case 3:
      r = p;
      g = q;
      b = v;
      break;

    case 4:
      r = t;
      g = p;
      b = v;
      break;

    case 5:
      r = v;
      g = p;
      b = q;
      break;
  }

  r = Math.round(r * 255.0);
  g = Math.round(g * 255.0);
  b = Math.round(b * 255.0);
  return {
    r: r,
    g: g,
    b: b,
    a: value.a
  };
};
var RGBToHSV = function RGBToHSV(value) {
  var h = 0,
      s = 0,
      v = 0;
  var r = value.r,
      g = value.g,
      b = value.b;
  var max = Math.max(r, g, b);
  var min = Math.min(r, g, b);
  v = max / 255;

  if (max === 0) {
    s = 0;
  } else {
    s = 1 - min / max;
  }

  if (max === min) {
    h = 0;
  } else if (max === r && g >= b) {
    h = 60 * ((g - b) / (max - min)) + 0;
  } else if (max === r && g < b) {
    h = 60 * ((g - b) / (max - min)) + 360;
  } else if (max === g) {
    h = 60 * ((b - r) / (max - min)) + 120;
  } else if (max === b) {
    h = 60 * ((r - g) / (max - min)) + 240;
  }

  h = Math.round(h * 100) / 100;
  s = Math.round(s * 100) / 100;
  v = Math.round(v * 100) / 100;
  return {
    h: h,
    s: s,
    v: v,
    a: value.a
  };
};
var RGBToHSL = function RGBToHSL(value) {
  var r = value.r / 255,
      g = value.g / 255,
      b = value.b / 255;
  var max = Math.max(r, g, b);
  var min = Math.min(r, g, b);
  var hue, saturation;
  var lightness = (min + max) / 2.0;

  if (min === max) {
    hue = 0;
    saturation = 0;
  } else {
    var delta = max - min;
    saturation = lightness <= 0.5 ? delta / (max + min) : delta / (2 - max - min);

    switch (max) {
      case r:
        hue = (g - b) / delta + (g < b ? 6 : 0);
        break;

      case g:
        hue = (b - r) / delta + 2;
        break;

      case b:
        hue = (r - g) / delta + 4;
        break;
    }

    hue /= 6;
  }

  return {
    h: hue * 360,
    s: saturation,
    l: lightness,
    a: value.a
  };
};

function clamp(value, min, max) {
  return Math.max(min, Math.min(max, value));
} // compute euclidian modulo of m % n
// https://en.wikipedia.org/wiki/Modulo_operation


function euclideanModulo(n, m) {
  return (n % m + m) % m;
}

var HSLToRGB = function HSLToRGB(value) {
  // h,s,l ranges are in 0.0 - 1.0
  var h = euclideanModulo(value.h / 360, 1);
  var s = clamp(value.s, 0, 1);
  var l = clamp(value.l, 0, 1);
  var r, g, b;

  if (s === 0) {
    r = g = b = l;
  } else {
    var p = l <= 0.5 ? l * (1 + s) : l + s - l * s;
    var q = 2 * l - p;
    r = hue2rgb(q, p, h + 1 / 3);
    g = hue2rgb(q, p, h);
    b = hue2rgb(q, p, h - 1 / 3);
  }

  return {
    r: r,
    g: g,
    b: b,
    a: 1.0
  };
};

function hue2rgb(p, q, t) {
  if (t < 0) t += 1;
  if (t > 1) t -= 1;
  if (t < 1 / 6) return Math.round((p + (q - p) * 6 * t) * 255);
  if (t < 1 / 2) return Math.round(q * 255);
  if (t < 2 / 3) return Math.round((p + (q - p) * 6 * (2 / 3 - t)) * 255);
  return Math.round(p * 255);
}

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
  try {
    var info = gen[key](arg);
    var value = info.value;
  } catch (error) {
    reject(error);
    return;
  }

  if (info.done) {
    resolve(value);
  } else {
    Promise.resolve(value).then(_next, _throw);
  }
}

function _asyncToGenerator(fn) {
  return function () {
    var self = this,
        args = arguments;
    return new Promise(function (resolve, reject) {
      var gen = fn.apply(self, args);

      function _next(value) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
      }

      function _throw(err) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
      }

      _next(undefined);
    });
  };
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _inheritsLoose(subClass, superClass) {
  subClass.prototype = Object.create(superClass.prototype);
  subClass.prototype.constructor = subClass;

  _setPrototypeOf(subClass, superClass);
}

function _setPrototypeOf(o, p) {
  _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
    o.__proto__ = p;
    return o;
  };

  return _setPrototypeOf(o, p);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var DragModal = /*#__PURE__*/function (_Component) {
  _inheritsLoose(DragModal, _Component);

  function DragModal() {
    var _this;

    _this = _Component.apply(this, arguments) || this;
    _this.draggleRef = React__default.createRef();
    _this.state = {
      modalDragDisabled: true,
      bounds: {
        left: 0,
        top: 0,
        bottom: 0,
        right: 0
      }
    };

    _this.onModalDragStart = function (_, uiData) {
      var _window, _window$document, _this$draggleRef, _this$draggleRef$curr;

      if (_this.props.dragForbidden) return;

      var _window$document$docu = (_window = window) == null ? void 0 : (_window$document = _window.document) == null ? void 0 : _window$document.documentElement,
          clientWidth = _window$document$docu.clientWidth,
          clientHeight = _window$document$docu.clientHeight;

      var targetRect = (_this$draggleRef = _this.draggleRef) == null ? void 0 : (_this$draggleRef$curr = _this$draggleRef.current) == null ? void 0 : _this$draggleRef$curr.getBoundingClientRect();

      _this.setState({
        bounds: {
          left: -(targetRect == null ? void 0 : targetRect.left) + (uiData == null ? void 0 : uiData.x),
          right: clientWidth - ((targetRect == null ? void 0 : targetRect.right) - (uiData == null ? void 0 : uiData.x)),
          top: -(targetRect == null ? void 0 : targetRect.top) + (uiData == null ? void 0 : uiData.y),
          bottom: clientHeight - ((targetRect == null ? void 0 : targetRect.bottom) - (uiData == null ? void 0 : uiData.y))
        }
      });
    };

    _this.onCancel = function (_) {
      if (_this.props.onClose) {
        _this.props.onClose();
      }
    };

    return _this;
  }

  var _proto = DragModal.prototype;

  _proto.render = function render() {
    var _this2 = this;

    var ModalDragger = React__default.createElement("div", {
      className: "modal-dragger",
      onMouseOver: function onMouseOver() {
        if (_this2.state.modalDragDisabled) {
          _this2.setState({
            modalDragDisabled: false
          });
        }
      },
      onMouseOut: function onMouseOut() {
        _this2.setState({
          modalDragDisabled: true
        });
      }
    }, React__default.createElement("span", {
      style: {
        userSelect: 'none'
      }
    }, this.props.title), React__default.createElement("span", {
      className: "fill-remaining-space"
    }), this.props.showCloseIcon && React__default.createElement(icons.CloseOutlined, {
      className: "modal-close",
      onClick: this.onCancel
    }));
    return React__default.createElement(antd.Modal, {
      getContainer: false,
      open: this.props.visible,
      onCancel: this.onCancel,
      title: this.props.showHeader ? ModalDragger : null,
      width: this.props.width || 520,
      mask: this.props.mask,
      maskClosable: false,
      // transitionName=""
      centered: this.props.centered,
      destroyOnClose: this.props.destroyOnClose || false,
      wrapClassName: (this.props.wrapClassName || '') + " drag-modal",
      closable: false,
      footer: null,
      style: this.props.style || null,
      forceRender: this.props.forceRender,
      modalRender: function modalRender(modal) {
        return React__default.createElement(Draggable, {
          disabled: _this2.state.modalDragDisabled || _this2.props.dragForbidden,
          bounds: _this2.state.bounds,
          onStart: function onStart(event, uiData) {
            return _this2.onModalDragStart(event, uiData);
          }
        }, React__default.createElement("div", {
          ref: _this2.draggleRef
        }, modal));
      }
    }, this.props.children);
  };

  return DragModal;
}(React.Component);
DragModal.defaultProps = {
  //一些属性的默认值
  centered: true,
  forceRender: false,
  dragForbidden: false,
  showCloseIcon: true,
  showHeader: true,
  mask: false
};

function HuePointer() {
  return React__default.createElement("div", {
    className: "hue-pointer"
  });
}

function ColorPalette(props) {
  var _useState = React.useState('#2c1698'),
      currentColor = _useState[0],
      setCurrentColor = _useState[1];

  var _useState2 = React.useState('#2c1698'),
      hex = _useState2[0],
      setHex = _useState2[1];

  var _useState3 = React.useState({
    h: 250.18867924528305,
    s: 0.7444395987788921,
    l: 0.34108375,
    a: 1
  }),
      hsl = _useState3[0],
      setHsl = _useState3[1];

  var _useState4 = React.useState({
    h: 250.18867924528305,
    s: 0.8534999999999999,
    v: 0.595,
    a: 1
  }),
      hsv = _useState4[0],
      setHsv = _useState4[1];

  var _useState5 = React.useState({
    r: 44,
    g: 22,
    b: 152,
    a: 1
  }),
      rgb = _useState5[0],
      setRgb = _useState5[1]; // const [oldHue, setOldHue] = useState<number>(250.18867924528305);


  var styles = {
    label: {
      display: 'block',
      textAlign: 'center',
      fontSize: '11px',
      color: '#222222',
      paddingTop: '3px',
      paddingBottom: '4px',
      textTransform: 'capitalize'
    },
    input: {
      border: 'none',
      fontSize: '11px',
      padding: '4px 10% 3px',
      boxShadow: 'rgb(204 204 204) 0px 0px 0px 1px inset',
      width: '100%'
    },
    wrap: {}
  };
  React.useEffect(function () {
    var hex = props.defaultColor || '#2C1698';
    var rgb = HexStringToRGB(hex);
    var hsl = RGBToHSL(rgb);
    var hsv = RGBToHSV(rgb);
    setHex(hex);
    setHsl(hsl);
    setHsv(hsv);
    setRgb(rgb);
    setCurrentColor(hex);
  }, []);

  var handleHueChange = function handleHueChange(color) {
    var tmp_hsl = color;
    var tmp_rgb = HSLToRGB(color);
    var tmp_hex = RGBToHexString(tmp_rgb);
    var tmp_hsv = RGBToHSV(tmp_rgb);
    setHex(tmp_hex);
    setHsl(tmp_hsl);
    setHsv(tmp_hsv);
    setRgb(tmp_rgb);
    setCurrentColor(tmp_hex); // setOldHue(tmp_hsl.h);
  };

  var handleSaturationChange = function handleSaturationChange(color) {
    var tmp_hsv = color;
    var tmp_rgb = HSVToRGB(tmp_hsv);
    var tmp_hex = RGBToHexString(tmp_rgb);
    var tmp_hsl = RGBToHSL(tmp_rgb);

    if (Math.floor(tmp_hsv.h) !== tmp_hsl.h && tmp_hsl.h === 0) {
      tmp_hsl.h = tmp_hsv.h;
    }

    setHex(tmp_hex);
    setHsl(tmp_hsl);
    setHsv(tmp_hsv);
    setRgb(tmp_rgb);
    setCurrentColor(tmp_hex); // setOldHue(tmp_hsl.h);
  };

  var handleHexChange = function handleHexChange(e) {
    var tmp_hex = e.hex || e;
    if (tmp_hex.length !== 4 && tmp_hex.length !== 7) return;
    var tmp_rgb = HexStringToRGB(tmp_hex);
    var tmp_hsl = RGBToHSL(tmp_rgb);
    var tmp_hsv = RGBToHSV(tmp_rgb);
    setHex(tmp_hex);
    setHsl(tmp_hsl);
    setHsv(tmp_hsv);
    setRgb(tmp_rgb);
    setCurrentColor(tmp_hex); // setOldHue(tmp_hsl.h);
  };

  var handleRGBChange = function handleRGBChange(color) {
    var tmp_rgb = _extends({}, rgb, color);

    var tmp_hsl = RGBToHSL(tmp_rgb);
    var tmp_hsv = RGBToHSV(tmp_rgb);
    var tmp_hex = RGBToHexString(tmp_rgb);
    setHex(tmp_hex);
    setHsl(tmp_hsl);
    setHsv(tmp_hsv);
    setRgb(tmp_rgb);
    setCurrentColor(tmp_hex); // setOldHue(tmp_hsl.h);
  };

  return React__default.createElement("div", {
    className: "tn-color-palette-container"
  }, React__default.createElement("div", {
    className: "left-panel"
  }, React__default.createElement("div", {
    className: "palette-saturation"
  }, React__default.createElement(common.Saturation, Object.assign({}, props, {
    hsl: hsl,
    hsv: hsv,
    onChange: handleSaturationChange
  }))), React__default.createElement("div", {
    className: "palette-hue"
  }, React__default.createElement(common.Hue, Object.assign({}, props, {
    hsl: hsl,
    onChange: handleHueChange,
    pointer: HuePointer
  })))), React__default.createElement("div", {
    className: "right-panel"
  }, React__default.createElement("div", {
    className: "color-wrapper"
  }, defaultColors.map(function (color, idx) {
    return React__default.createElement(antd.Tooltip, {
      title: color,
      key: idx,
      color: "#fff",
      overlayClassName: "color-tooltip"
    }, React__default.createElement("div", {
      className: "color-item",
      onClick: function onClick() {
        return handleHexChange(color);
      }
    }, React__default.createElement("div", {
      className: "color-box",
      style: {
        backgroundColor: color
      }
    })));
  })), React__default.createElement("div", {
    className: "input-wrapper"
  }, React__default.createElement("div", {
    className: "input-item-hex"
  }, React__default.createElement(common.EditableInput, {
    label: "hex",
    value: hex,
    onChange: handleHexChange,
    //@ts-ignore
    style: styles
  })), React__default.createElement("div", {
    className: "fill-remaining-space"
  }), React__default.createElement("div", {
    className: "input-item-rgb"
  }, React__default.createElement(common.EditableInput, {
    label: "r",
    value: rgb == null ? void 0 : rgb.r,
    onChange: handleRGBChange,
    //@ts-ignore
    style: styles
  })), React__default.createElement("div", {
    className: "input-item-rgb"
  }, React__default.createElement(common.EditableInput, {
    label: "g",
    value: rgb == null ? void 0 : rgb.g,
    onChange: handleRGBChange,
    //@ts-ignore
    style: styles
  })), React__default.createElement("div", {
    className: "input-item-rgb"
  }, React__default.createElement(common.EditableInput, {
    label: "b",
    value: rgb == null ? void 0 : rgb.b,
    onChange: handleRGBChange,
    //@ts-ignore
    style: styles
  }))), React__default.createElement("span", {
    className: "fill-remaining-space"
  }), React__default.createElement("div", {
    className: "color-footer"
  }, React__default.createElement("div", {
    className: "current-color",
    style: {
      backgroundColor: currentColor
    }
  }), React__default.createElement("span", {
    className: "fill-remaining-space"
  }), React__default.createElement(antd.Space, null, React__default.createElement(antd.Button, {
    size: "small",
    type: "primary",
    onClick: function onClick() {
      if (props.onComplete) {
        props.onComplete(currentColor);
      }
    }
  }, "\u786E\u5B9A"), React__default.createElement(antd.Button, {
    size: "small",
    onClick: function onClick() {
      if (props.onCancel) {
        props.onCancel();
      }
    }
  }, "\u53D6\u6D88")))));
}
var ColorPalette$1 = /*#__PURE__*/reactColor.CustomPicker(ColorPalette);
var defaultColors = ['#4D4D4D', '#999999', '#FFFFFF', '#F44E3B', '#FE9200', '#FCDC00', '#DBDF00', '#A4DD00', '#68CCCA', '#73D8FF', '#AEA1FF', '#FDA1FF', '#333333', '#808080', '#cccccc', '#D33115', '#E27300', '#FCC400', '#B0BC00', '#68BC00', '#16A5A5', '#009CE0', '#7B64FF', '#FA28FF', '#000000', '#666666', '#B3B3B3', '#9F0500', '#C45100', '#FB9E00', '#808900', '#194D33', '#0C797D', '#0062B1', '#653294', '#AB149E'];

var colorList = ['#000000', '#f8d731', '#cd6928', '#991b1e', '#642165', '#293189', '#22346e', '#136734', '#727430', '#636466', '#f1eb1f', '#f26722', '#cd2027', '#93278f', '#4554a5', '#105689', '#139b48', '#999b37', '#939598', '#f4ee51', '#f8991e', '#ed1f24', '#a953a0', '#5e67af', '#2776bb', '#58ba48', '#c8c92d', '#c7c8ca', '#f7f281', '#fecc66', '#f27172', '#d19cc7', '#9898cc', '#7aafdf', '#afd9aa', '#e5e878', '#ffffff', '#f8f6b0', '#feeab9', '#f7abae', '#ddb3d4', '#cecce6', '#adddf7', '#d7ebd2', '#edee99'];
var indexColorList = ['#ff0000', '#ffff00', '#00ff00', '#00ffff', '#0000ff', '#ff00ff', '#ffffff', '#808080', '#c0c0c0'];
function ColorSelect(props) {
  var _useState = React.useState(false),
      colorPaletteOpen = _useState[0],
      setColorPaletteOpen = _useState[1];

  var content = React__default.createElement("div", {
    className: "color-select-dropdown"
  }, React__default.createElement("div", {
    className: "tn-color-select"
  }, React__default.createElement("div", {
    className: "color-wrapper"
  }, colorList.map(function (color, idx) {
    return React__default.createElement(antd.Tooltip, {
      title: color,
      key: idx,
      color: "#fff",
      overlayClassName: "color-tooltip"
    }, React__default.createElement("div", {
      className: "color-item",
      onClick: function onClick() {
        props.onSelectChanged(color);
      }
    }, React__default.createElement("div", {
      className: "color-box",
      style: {
        backgroundColor: color
      }
    })));
  }))), React__default.createElement("div", {
    className: "color-select"
  }, React__default.createElement("div", null, "\u7D22\u5F15\u989C\u8272"), React__default.createElement("div", {
    className: "color-wrapper"
  }, indexColorList.map(function (color, idx) {
    return React__default.createElement(antd.Tooltip, {
      title: HexStringToKeywords[color] || color,
      key: idx,
      color: "#fff",
      overlayClassName: "color-tooltip"
    }, React__default.createElement("div", {
      className: "color-item",
      onClick: function onClick() {
        props.onSelectChanged(color);
      }
    }, React__default.createElement("div", {
      className: "color-box",
      style: {
        backgroundColor: color
      }
    })));
  }))), React__default.createElement("div", null, React__default.createElement("div", {
    className: "click-select",
    style: {
      marginTop: '4px'
    },
    onClick: function onClick() {
      setColorPaletteOpen(true);
    }
  }, React__default.createElement("span", null, "\u66F4\u591A\u989C\u8272..."))));
  return React__default.createElement("div", {
    className: "color-select"
  }, React__default.createElement(DragModal, {
    title: "\u9009\u62E9\u989C\u8272",
    visible: props.visible,
    width: 220,
    onClose: props.onClose
  }, content), React__default.createElement(DragModal, {
    title: "\u9009\u62E9\u989C\u8272",
    visible: colorPaletteOpen,
    width: 550,
    wrapClassName: "color-select-modal",
    onClose: function onClose() {
      setColorPaletteOpen(false);
    }
  }, React__default.createElement("div", {
    className: "color-select-modal-body"
  }, React__default.createElement(ColorPalette$1, {
    onCancel: function onCancel() {
      setColorPaletteOpen(false);
    },
    onComplete: function onComplete(color) {
      setColorPaletteOpen(false);
      props.onSelectChanged(color);
    }
  }))));
}

/**
 * 通用组件-内置了dayjs的日期选择器
 *
 * 部分参数：
 * @param showTime: { minuteStep: number, showHour: boolean, showMinute: boolean, showSecond: boolean }
 * @param onChange: () => void
 * @param format: string  //输出格式
 * @param placeholder: string   //未选择时间是的占位符
 */

var DatePicker = /*#__PURE__*/generatePicker(dayjsGenerateConfig);

var _lut = [];

for (var i = 0; i < 256; i++) {
  _lut[i] = (i < 16 ? '0' : '') + /*#__PURE__*/i.toString(16);
}

function genUUID() {
  var d0 = Math.random() * 0xffffffff | 0;
  var d1 = Math.random() * 0xffffffff | 0;
  var d2 = Math.random() * 0xffffffff | 0;
  var d3 = Math.random() * 0xffffffff | 0;
  var uuid = _lut[d0 & 0xff] + _lut[d0 >> 8 & 0xff] + _lut[d0 >> 16 & 0xff] + _lut[d0 >> 24 & 0xff] + '-' + _lut[d1 & 0xff] + _lut[d1 >> 8 & 0xff] + '-' + _lut[d1 >> 16 & 0x0f | 0x40] + _lut[d1 >> 24 & 0xff] + '-' + _lut[d2 & 0x3f | 0x80] + _lut[d2 >> 8 & 0xff] + '-' + _lut[d2 >> 16 & 0xff] + _lut[d2 >> 24 & 0xff] + _lut[d3 & 0xff] + _lut[d3 >> 8 & 0xff] + _lut[d3 >> 16 & 0xff] + _lut[d3 >> 24 & 0xff]; // .toUpperCase() here flattens concatenated strings to save heap memory space.
  // return uuid.toUpperCase().replace(/-/g, '');

  return uuid;
}

/**
 * 用echarts封装的x轴为离散轴的组件
 * echarts中option的具体配置法详见：   https://echarts.apache.org/zh/option.html
 *  */
function CategoryEChart(props) {
  var uuid = genUUID();

  var _useState = React.useState(),
      showChart = _useState[0],
      setShowChart = _useState[1];

  React.useEffect(function () {
    if (!showChart) {
      var tmpChart = echarts.init(document.getElementById(uuid));
      tmpChart.resize({
        height: props.height,
        width: props.width
      });
      tmpChart.setOption(generateOption());
      setShowChart(tmpChart);
    }
  }, []);
  React.useEffect(function () {
    if (showChart) {
      showChart.setOption(generateOption());
    }
  }, [props.q_data]);
  React.useEffect(function () {
    if (showChart) {
      if (props.width) {
        showChart.resize({
          height: props.height,
          width: props.width
        });
      } else {
        showChart.resize({
          height: props.height,
          width: document.body.clientWidth
        });
      }
    }
  }, [props.height, props.width]);
  React.useEffect(function () {}, [showChart]);

  var generateOption = function generateOption() {
    var series = [];

    if (props.q_data.length === 0) ; else {
      if (props.q_data[0].legendName) {
        //如果legendName存在，为三维数据
        var data_dict = {};
        props.q_data.forEach(function (datePoint) {
          if (data_dict.hasOwnProperty(datePoint.legendName)) {
            data_dict[datePoint.legendName].push([datePoint.axisName, datePoint.value.toFixed(props.precision)]);
          } else {
            data_dict[datePoint.legendName] = [];
            data_dict[datePoint.legendName].push([datePoint.axisName, datePoint.value.toFixed(props.precision)]);
          }
        });
        Object.keys(data_dict).forEach(function (legendName) {
          series.push({
            name: legendName,
            data: data_dict[legendName],
            type: props.type
          });
        });
      } else {
        //legendName不存在，为二维数据
        var data = [];
        props.q_data.forEach(function (datePoint) {
          data.push([datePoint.axisName, datePoint.value.toFixed(props.precision)]);
        });
        series = [{
          data: data,
          type: props.type,
          color: props.color,
          barWidth: '35%'
        }];
      }
    }

    return {
      legend: {
        top: "2.5%",
        right: "2%",
        orient: "horizontal",
        itemGap: 25
      },
      grid: props.padding,
      xAxis: {
        type: 'category',
        splitLine: {
          show: false
        },
        boundaryGap: true,
        axisTick: {
          alignWithLabel: true
        }
      },
      yAxis: {
        type: 'value',
        min: function min(value) {
          return Math.max(value.min - 20, 0);
        }
      },
      tooltip: {
        trigger: 'axis',
        axisPointer: {
          type: "shadow"
        }
      },
      series: series
    };
  };

  return React__default.createElement("div", {
    className: 'category-echart',
    id: uuid
  });
}
CategoryEChart.defaultProps = {
  q_data: [],
  precision: 0,
  height: 250,
  type: "line",
  color: "#eaeaea",
  padding: {}
};

var TabPane = antd.Tabs.TabPane;
function ClosableTabs(props) {
  return React__default.createElement("div", {
    className: "tn-common-container tn-common"
  }, React__default.createElement(antd.Tabs, {
    className: "tn-common-closable-tabs",
    type: "editable-card",
    activeKey: props.selectedKey ? props.selectedKey : "1",
    hideAdd: true,
    onChange: props.onChange,
    onEdit: props.onClose,
    tabBarExtraContent: React__default.createElement(antd.Button, {
      type: "link",
      onClick: props.onCloseAll,
      icon: React__default.createElement(icons.ClearOutlined, null)
    }, "\u5168\u90E8\u5173\u95ED")
  }, props.panes.map(function (pane) {
    return React__default.createElement(TabPane, {
      tab: pane.title,
      key: pane.uuid,
      closable: pane.closable
    });
  })));
}

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

var runtime_1 = createCommonjsModule(function (module) {
/**
 * Copyright (c) 2014-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

var runtime = (function (exports) {

  var Op = Object.prototype;
  var hasOwn = Op.hasOwnProperty;
  var defineProperty = Object.defineProperty || function (obj, key, desc) { obj[key] = desc.value; };
  var undefined$1; // More compressible than void 0.
  var $Symbol = typeof Symbol === "function" ? Symbol : {};
  var iteratorSymbol = $Symbol.iterator || "@@iterator";
  var asyncIteratorSymbol = $Symbol.asyncIterator || "@@asyncIterator";
  var toStringTagSymbol = $Symbol.toStringTag || "@@toStringTag";

  function define(obj, key, value) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
    return obj[key];
  }
  try {
    // IE 8 has a broken Object.defineProperty that only works on DOM objects.
    define({}, "");
  } catch (err) {
    define = function(obj, key, value) {
      return obj[key] = value;
    };
  }

  function wrap(innerFn, outerFn, self, tryLocsList) {
    // If outerFn provided and outerFn.prototype is a Generator, then outerFn.prototype instanceof Generator.
    var protoGenerator = outerFn && outerFn.prototype instanceof Generator ? outerFn : Generator;
    var generator = Object.create(protoGenerator.prototype);
    var context = new Context(tryLocsList || []);

    // The ._invoke method unifies the implementations of the .next,
    // .throw, and .return methods.
    defineProperty(generator, "_invoke", { value: makeInvokeMethod(innerFn, self, context) });

    return generator;
  }
  exports.wrap = wrap;

  // Try/catch helper to minimize deoptimizations. Returns a completion
  // record like context.tryEntries[i].completion. This interface could
  // have been (and was previously) designed to take a closure to be
  // invoked without arguments, but in all the cases we care about we
  // already have an existing method we want to call, so there's no need
  // to create a new function object. We can even get away with assuming
  // the method takes exactly one argument, since that happens to be true
  // in every case, so we don't have to touch the arguments object. The
  // only additional allocation required is the completion record, which
  // has a stable shape and so hopefully should be cheap to allocate.
  function tryCatch(fn, obj, arg) {
    try {
      return { type: "normal", arg: fn.call(obj, arg) };
    } catch (err) {
      return { type: "throw", arg: err };
    }
  }

  var GenStateSuspendedStart = "suspendedStart";
  var GenStateSuspendedYield = "suspendedYield";
  var GenStateExecuting = "executing";
  var GenStateCompleted = "completed";

  // Returning this object from the innerFn has the same effect as
  // breaking out of the dispatch switch statement.
  var ContinueSentinel = {};

  // Dummy constructor functions that we use as the .constructor and
  // .constructor.prototype properties for functions that return Generator
  // objects. For full spec compliance, you may wish to configure your
  // minifier not to mangle the names of these two functions.
  function Generator() {}
  function GeneratorFunction() {}
  function GeneratorFunctionPrototype() {}

  // This is a polyfill for %IteratorPrototype% for environments that
  // don't natively support it.
  var IteratorPrototype = {};
  define(IteratorPrototype, iteratorSymbol, function () {
    return this;
  });

  var getProto = Object.getPrototypeOf;
  var NativeIteratorPrototype = getProto && getProto(getProto(values([])));
  if (NativeIteratorPrototype &&
      NativeIteratorPrototype !== Op &&
      hasOwn.call(NativeIteratorPrototype, iteratorSymbol)) {
    // This environment has a native %IteratorPrototype%; use it instead
    // of the polyfill.
    IteratorPrototype = NativeIteratorPrototype;
  }

  var Gp = GeneratorFunctionPrototype.prototype =
    Generator.prototype = Object.create(IteratorPrototype);
  GeneratorFunction.prototype = GeneratorFunctionPrototype;
  defineProperty(Gp, "constructor", { value: GeneratorFunctionPrototype, configurable: true });
  defineProperty(
    GeneratorFunctionPrototype,
    "constructor",
    { value: GeneratorFunction, configurable: true }
  );
  GeneratorFunction.displayName = define(
    GeneratorFunctionPrototype,
    toStringTagSymbol,
    "GeneratorFunction"
  );

  // Helper for defining the .next, .throw, and .return methods of the
  // Iterator interface in terms of a single ._invoke method.
  function defineIteratorMethods(prototype) {
    ["next", "throw", "return"].forEach(function(method) {
      define(prototype, method, function(arg) {
        return this._invoke(method, arg);
      });
    });
  }

  exports.isGeneratorFunction = function(genFun) {
    var ctor = typeof genFun === "function" && genFun.constructor;
    return ctor
      ? ctor === GeneratorFunction ||
        // For the native GeneratorFunction constructor, the best we can
        // do is to check its .name property.
        (ctor.displayName || ctor.name) === "GeneratorFunction"
      : false;
  };

  exports.mark = function(genFun) {
    if (Object.setPrototypeOf) {
      Object.setPrototypeOf(genFun, GeneratorFunctionPrototype);
    } else {
      genFun.__proto__ = GeneratorFunctionPrototype;
      define(genFun, toStringTagSymbol, "GeneratorFunction");
    }
    genFun.prototype = Object.create(Gp);
    return genFun;
  };

  // Within the body of any async function, `await x` is transformed to
  // `yield regeneratorRuntime.awrap(x)`, so that the runtime can test
  // `hasOwn.call(value, "__await")` to determine if the yielded value is
  // meant to be awaited.
  exports.awrap = function(arg) {
    return { __await: arg };
  };

  function AsyncIterator(generator, PromiseImpl) {
    function invoke(method, arg, resolve, reject) {
      var record = tryCatch(generator[method], generator, arg);
      if (record.type === "throw") {
        reject(record.arg);
      } else {
        var result = record.arg;
        var value = result.value;
        if (value &&
            typeof value === "object" &&
            hasOwn.call(value, "__await")) {
          return PromiseImpl.resolve(value.__await).then(function(value) {
            invoke("next", value, resolve, reject);
          }, function(err) {
            invoke("throw", err, resolve, reject);
          });
        }

        return PromiseImpl.resolve(value).then(function(unwrapped) {
          // When a yielded Promise is resolved, its final value becomes
          // the .value of the Promise<{value,done}> result for the
          // current iteration.
          result.value = unwrapped;
          resolve(result);
        }, function(error) {
          // If a rejected Promise was yielded, throw the rejection back
          // into the async generator function so it can be handled there.
          return invoke("throw", error, resolve, reject);
        });
      }
    }

    var previousPromise;

    function enqueue(method, arg) {
      function callInvokeWithMethodAndArg() {
        return new PromiseImpl(function(resolve, reject) {
          invoke(method, arg, resolve, reject);
        });
      }

      return previousPromise =
        // If enqueue has been called before, then we want to wait until
        // all previous Promises have been resolved before calling invoke,
        // so that results are always delivered in the correct order. If
        // enqueue has not been called before, then it is important to
        // call invoke immediately, without waiting on a callback to fire,
        // so that the async generator function has the opportunity to do
        // any necessary setup in a predictable way. This predictability
        // is why the Promise constructor synchronously invokes its
        // executor callback, and why async functions synchronously
        // execute code before the first await. Since we implement simple
        // async functions in terms of async generators, it is especially
        // important to get this right, even though it requires care.
        previousPromise ? previousPromise.then(
          callInvokeWithMethodAndArg,
          // Avoid propagating failures to Promises returned by later
          // invocations of the iterator.
          callInvokeWithMethodAndArg
        ) : callInvokeWithMethodAndArg();
    }

    // Define the unified helper method that is used to implement .next,
    // .throw, and .return (see defineIteratorMethods).
    defineProperty(this, "_invoke", { value: enqueue });
  }

  defineIteratorMethods(AsyncIterator.prototype);
  define(AsyncIterator.prototype, asyncIteratorSymbol, function () {
    return this;
  });
  exports.AsyncIterator = AsyncIterator;

  // Note that simple async functions are implemented on top of
  // AsyncIterator objects; they just return a Promise for the value of
  // the final result produced by the iterator.
  exports.async = function(innerFn, outerFn, self, tryLocsList, PromiseImpl) {
    if (PromiseImpl === void 0) PromiseImpl = Promise;

    var iter = new AsyncIterator(
      wrap(innerFn, outerFn, self, tryLocsList),
      PromiseImpl
    );

    return exports.isGeneratorFunction(outerFn)
      ? iter // If outerFn is a generator, return the full iterator.
      : iter.next().then(function(result) {
          return result.done ? result.value : iter.next();
        });
  };

  function makeInvokeMethod(innerFn, self, context) {
    var state = GenStateSuspendedStart;

    return function invoke(method, arg) {
      if (state === GenStateExecuting) {
        throw new Error("Generator is already running");
      }

      if (state === GenStateCompleted) {
        if (method === "throw") {
          throw arg;
        }

        // Be forgiving, per 25.3.3.3.3 of the spec:
        // https://people.mozilla.org/~jorendorff/es6-draft.html#sec-generatorresume
        return doneResult();
      }

      context.method = method;
      context.arg = arg;

      while (true) {
        var delegate = context.delegate;
        if (delegate) {
          var delegateResult = maybeInvokeDelegate(delegate, context);
          if (delegateResult) {
            if (delegateResult === ContinueSentinel) continue;
            return delegateResult;
          }
        }

        if (context.method === "next") {
          // Setting context._sent for legacy support of Babel's
          // function.sent implementation.
          context.sent = context._sent = context.arg;

        } else if (context.method === "throw") {
          if (state === GenStateSuspendedStart) {
            state = GenStateCompleted;
            throw context.arg;
          }

          context.dispatchException(context.arg);

        } else if (context.method === "return") {
          context.abrupt("return", context.arg);
        }

        state = GenStateExecuting;

        var record = tryCatch(innerFn, self, context);
        if (record.type === "normal") {
          // If an exception is thrown from innerFn, we leave state ===
          // GenStateExecuting and loop back for another invocation.
          state = context.done
            ? GenStateCompleted
            : GenStateSuspendedYield;

          if (record.arg === ContinueSentinel) {
            continue;
          }

          return {
            value: record.arg,
            done: context.done
          };

        } else if (record.type === "throw") {
          state = GenStateCompleted;
          // Dispatch the exception by looping back around to the
          // context.dispatchException(context.arg) call above.
          context.method = "throw";
          context.arg = record.arg;
        }
      }
    };
  }

  // Call delegate.iterator[context.method](context.arg) and handle the
  // result, either by returning a { value, done } result from the
  // delegate iterator, or by modifying context.method and context.arg,
  // setting context.delegate to null, and returning the ContinueSentinel.
  function maybeInvokeDelegate(delegate, context) {
    var method = delegate.iterator[context.method];
    if (method === undefined$1) {
      // A .throw or .return when the delegate iterator has no .throw
      // method always terminates the yield* loop.
      context.delegate = null;

      if (context.method === "throw") {
        // Note: ["return"] must be used for ES3 parsing compatibility.
        if (delegate.iterator["return"]) {
          // If the delegate iterator has a return method, give it a
          // chance to clean up.
          context.method = "return";
          context.arg = undefined$1;
          maybeInvokeDelegate(delegate, context);

          if (context.method === "throw") {
            // If maybeInvokeDelegate(context) changed context.method from
            // "return" to "throw", let that override the TypeError below.
            return ContinueSentinel;
          }
        }

        context.method = "throw";
        context.arg = new TypeError(
          "The iterator does not provide a 'throw' method");
      }

      return ContinueSentinel;
    }

    var record = tryCatch(method, delegate.iterator, context.arg);

    if (record.type === "throw") {
      context.method = "throw";
      context.arg = record.arg;
      context.delegate = null;
      return ContinueSentinel;
    }

    var info = record.arg;

    if (! info) {
      context.method = "throw";
      context.arg = new TypeError("iterator result is not an object");
      context.delegate = null;
      return ContinueSentinel;
    }

    if (info.done) {
      // Assign the result of the finished delegate to the temporary
      // variable specified by delegate.resultName (see delegateYield).
      context[delegate.resultName] = info.value;

      // Resume execution at the desired location (see delegateYield).
      context.next = delegate.nextLoc;

      // If context.method was "throw" but the delegate handled the
      // exception, let the outer generator proceed normally. If
      // context.method was "next", forget context.arg since it has been
      // "consumed" by the delegate iterator. If context.method was
      // "return", allow the original .return call to continue in the
      // outer generator.
      if (context.method !== "return") {
        context.method = "next";
        context.arg = undefined$1;
      }

    } else {
      // Re-yield the result returned by the delegate method.
      return info;
    }

    // The delegate iterator is finished, so forget it and continue with
    // the outer generator.
    context.delegate = null;
    return ContinueSentinel;
  }

  // Define Generator.prototype.{next,throw,return} in terms of the
  // unified ._invoke helper method.
  defineIteratorMethods(Gp);

  define(Gp, toStringTagSymbol, "Generator");

  // A Generator should always return itself as the iterator object when the
  // @@iterator function is called on it. Some browsers' implementations of the
  // iterator prototype chain incorrectly implement this, causing the Generator
  // object to not be returned from this call. This ensures that doesn't happen.
  // See https://github.com/facebook/regenerator/issues/274 for more details.
  define(Gp, iteratorSymbol, function() {
    return this;
  });

  define(Gp, "toString", function() {
    return "[object Generator]";
  });

  function pushTryEntry(locs) {
    var entry = { tryLoc: locs[0] };

    if (1 in locs) {
      entry.catchLoc = locs[1];
    }

    if (2 in locs) {
      entry.finallyLoc = locs[2];
      entry.afterLoc = locs[3];
    }

    this.tryEntries.push(entry);
  }

  function resetTryEntry(entry) {
    var record = entry.completion || {};
    record.type = "normal";
    delete record.arg;
    entry.completion = record;
  }

  function Context(tryLocsList) {
    // The root entry object (effectively a try statement without a catch
    // or a finally block) gives us a place to store values thrown from
    // locations where there is no enclosing try statement.
    this.tryEntries = [{ tryLoc: "root" }];
    tryLocsList.forEach(pushTryEntry, this);
    this.reset(true);
  }

  exports.keys = function(val) {
    var object = Object(val);
    var keys = [];
    for (var key in object) {
      keys.push(key);
    }
    keys.reverse();

    // Rather than returning an object with a next method, we keep
    // things simple and return the next function itself.
    return function next() {
      while (keys.length) {
        var key = keys.pop();
        if (key in object) {
          next.value = key;
          next.done = false;
          return next;
        }
      }

      // To avoid creating an additional object, we just hang the .value
      // and .done properties off the next function object itself. This
      // also ensures that the minifier will not anonymize the function.
      next.done = true;
      return next;
    };
  };

  function values(iterable) {
    if (iterable) {
      var iteratorMethod = iterable[iteratorSymbol];
      if (iteratorMethod) {
        return iteratorMethod.call(iterable);
      }

      if (typeof iterable.next === "function") {
        return iterable;
      }

      if (!isNaN(iterable.length)) {
        var i = -1, next = function next() {
          while (++i < iterable.length) {
            if (hasOwn.call(iterable, i)) {
              next.value = iterable[i];
              next.done = false;
              return next;
            }
          }

          next.value = undefined$1;
          next.done = true;

          return next;
        };

        return next.next = next;
      }
    }

    // Return an iterator with no values.
    return { next: doneResult };
  }
  exports.values = values;

  function doneResult() {
    return { value: undefined$1, done: true };
  }

  Context.prototype = {
    constructor: Context,

    reset: function(skipTempReset) {
      this.prev = 0;
      this.next = 0;
      // Resetting context._sent for legacy support of Babel's
      // function.sent implementation.
      this.sent = this._sent = undefined$1;
      this.done = false;
      this.delegate = null;

      this.method = "next";
      this.arg = undefined$1;

      this.tryEntries.forEach(resetTryEntry);

      if (!skipTempReset) {
        for (var name in this) {
          // Not sure about the optimal order of these conditions:
          if (name.charAt(0) === "t" &&
              hasOwn.call(this, name) &&
              !isNaN(+name.slice(1))) {
            this[name] = undefined$1;
          }
        }
      }
    },

    stop: function() {
      this.done = true;

      var rootEntry = this.tryEntries[0];
      var rootRecord = rootEntry.completion;
      if (rootRecord.type === "throw") {
        throw rootRecord.arg;
      }

      return this.rval;
    },

    dispatchException: function(exception) {
      if (this.done) {
        throw exception;
      }

      var context = this;
      function handle(loc, caught) {
        record.type = "throw";
        record.arg = exception;
        context.next = loc;

        if (caught) {
          // If the dispatched exception was caught by a catch block,
          // then let that catch block handle the exception normally.
          context.method = "next";
          context.arg = undefined$1;
        }

        return !! caught;
      }

      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        var record = entry.completion;

        if (entry.tryLoc === "root") {
          // Exception thrown outside of any try block that could handle
          // it, so set the completion value of the entire function to
          // throw the exception.
          return handle("end");
        }

        if (entry.tryLoc <= this.prev) {
          var hasCatch = hasOwn.call(entry, "catchLoc");
          var hasFinally = hasOwn.call(entry, "finallyLoc");

          if (hasCatch && hasFinally) {
            if (this.prev < entry.catchLoc) {
              return handle(entry.catchLoc, true);
            } else if (this.prev < entry.finallyLoc) {
              return handle(entry.finallyLoc);
            }

          } else if (hasCatch) {
            if (this.prev < entry.catchLoc) {
              return handle(entry.catchLoc, true);
            }

          } else if (hasFinally) {
            if (this.prev < entry.finallyLoc) {
              return handle(entry.finallyLoc);
            }

          } else {
            throw new Error("try statement without catch or finally");
          }
        }
      }
    },

    abrupt: function(type, arg) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.tryLoc <= this.prev &&
            hasOwn.call(entry, "finallyLoc") &&
            this.prev < entry.finallyLoc) {
          var finallyEntry = entry;
          break;
        }
      }

      if (finallyEntry &&
          (type === "break" ||
           type === "continue") &&
          finallyEntry.tryLoc <= arg &&
          arg <= finallyEntry.finallyLoc) {
        // Ignore the finally entry if control is not jumping to a
        // location outside the try/catch block.
        finallyEntry = null;
      }

      var record = finallyEntry ? finallyEntry.completion : {};
      record.type = type;
      record.arg = arg;

      if (finallyEntry) {
        this.method = "next";
        this.next = finallyEntry.finallyLoc;
        return ContinueSentinel;
      }

      return this.complete(record);
    },

    complete: function(record, afterLoc) {
      if (record.type === "throw") {
        throw record.arg;
      }

      if (record.type === "break" ||
          record.type === "continue") {
        this.next = record.arg;
      } else if (record.type === "return") {
        this.rval = this.arg = record.arg;
        this.method = "return";
        this.next = "end";
      } else if (record.type === "normal" && afterLoc) {
        this.next = afterLoc;
      }

      return ContinueSentinel;
    },

    finish: function(finallyLoc) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.finallyLoc === finallyLoc) {
          this.complete(entry.completion, entry.afterLoc);
          resetTryEntry(entry);
          return ContinueSentinel;
        }
      }
    },

    "catch": function(tryLoc) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.tryLoc === tryLoc) {
          var record = entry.completion;
          if (record.type === "throw") {
            var thrown = record.arg;
            resetTryEntry(entry);
          }
          return thrown;
        }
      }

      // The context.catch method must only be called with a location
      // argument that corresponds to a known catch block.
      throw new Error("illegal catch attempt");
    },

    delegateYield: function(iterable, resultName, nextLoc) {
      this.delegate = {
        iterator: values(iterable),
        resultName: resultName,
        nextLoc: nextLoc
      };

      if (this.method === "next") {
        // Deliberately forget the last sent value so that we don't
        // accidentally pass it on to the delegate.
        this.arg = undefined$1;
      }

      return ContinueSentinel;
    }
  };

  // Regardless of whether this script is executing as a CommonJS module
  // or not, return the runtime object so that we can declare the variable
  // regeneratorRuntime in the outer scope, which allows this module to be
  // injected easily by `bin/regenerator --include-runtime script.js`.
  return exports;

}(
  // If this script is executing as a CommonJS module, use module.exports
  // as the regeneratorRuntime namespace. Otherwise create a new empty
  // object. Either way, the resulting object will be used to initialize
  // the regeneratorRuntime variable at the top of this file.
   module.exports 
));

try {
  regeneratorRuntime = runtime;
} catch (accidentalStrictMode) {
  // This module should not be running in strict mode, so the above
  // assignment should always work unless something is misconfigured. Just
  // in case runtime.js accidentally runs in strict mode, in modern engines
  // we can explicitly access globalThis. In older engines we can escape
  // strict mode using a global Function call. This could conceivably fail
  // if a Content Security Policy forbids using Function, but in that case
  // the proper solution is to fix the accidental strict mode problem. If
  // you've misconfigured your bundler to force strict mode and applied a
  // CSP to forbid Function, and you're not willing to fix either of those
  // problems, please detail your unique predicament in a GitHub issue.
  if (typeof globalThis === "object") {
    globalThis.regeneratorRuntime = runtime;
  } else {
    Function("r", "regeneratorRuntime = r")(runtime);
  }
}
});

function TabItemLink(props) {
  var _useState = React.useState(false),
      visible = _useState[0],
      setVisible = _useState[1];

  var tabRoute = props.tabRoute;
  var navigate = reactRouterDom.useNavigate();
  var urlPrefix = '';

  for (var i = 0; i < props.tabInPage; i++) {
    urlPrefix += '../';
  }

  var resolved = reactRouterDom.useResolvedPath("" + urlPrefix + tabRoute.url);
  var match = reactRouterDom.useMatch({
    path: resolved.pathname + "/*"
  });
  var ref = React.useRef();

  var handleVisibleChange = function handleVisibleChange(newVisible, e) {
    if (!newVisible) {
      setVisible(newVisible);
      return;
    }

    if (tabRoute.popConfirm) {
      setVisible(newVisible);
    } else {
      confirm(e); // next step
    }
  };

  function confirm(_x) {
    return _confirm.apply(this, arguments);
  }

  function _confirm() {
    _confirm = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee(_) {
      return runtime_1.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              setVisible(false);

              if (!tabRoute.closeCallbackFn) {
                _context.next = 4;
                break;
              }

              _context.next = 4;
              return tabRoute.closeCallbackFn(tabRoute);

            case 4:
              if (props.onClose) props.onClose(tabRoute, !!match);

            case 5:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    }));
    return _confirm.apply(this, arguments);
  }

  var onItemClick = function onItemClick(_) {
    if (!!match) return;
    var ele = ref.current;
    ele.scrollIntoView();
    navigate("" + urlPrefix + tabRoute.url, {
      replace: true
    });
  };

  return React__default.createElement("div", {
    className: classNames({
      "tab-item": true,
      "active": !!match
    }),
    style: {
      backgroundColor: !!match ? (tabRoute == null ? void 0 : tabRoute.themeColor) || props.theme : null
    },
    onClick: onItemClick,
    ref: ref
  }, React__default.createElement("div", {
    className: "content"
  }, React__default.createElement("div", null, tabRoute.title)), (tabRoute == null ? void 0 : tabRoute.closable) && React__default.createElement(antd.Popconfirm, {
    title: "\u786E\u8BA4\u5220\u9664?",
    open: visible,
    onOpenChange: handleVisibleChange,
    onCancel: function onCancel(e) {
      e.stopPropagation();
      setVisible(false);
    },
    onConfirm: function onConfirm(e) {
      e.stopPropagation();
      confirm(e);
    },
    okText: "\u662F",
    cancelText: "\u5426"
  }, React__default.createElement(antd.Button, {
    type: "text",
    size: "small",
    className: "ope",
    icon: React__default.createElement(icons.CloseOutlined, null),
    onClick: function onClick(e) {
      return e.stopPropagation();
    }
  })));
}

var useCommonTabbarService = function useCommonTabbarService() {
  var _useState = React.useState([]),
      routes = _useState[0],
      setRoutes = _useState[1];

  var _useState2 = React.useState(null),
      themeColor = _useState2[0],
      setThemeColor = _useState2[1];

  var setRoutesOverwrite = React.useCallback(function (value) {
    setRoutes([].concat(value));
  }, []);
  var changeTheme = React.useCallback(function (value) {
    setThemeColor(value);
  }, []);

  var pushRoute = function pushRoute(value) {
    setRoutes(function (prev) {
      var idx = prev.findIndex(function (item) {
        return item.url === value.url;
      });

      if (idx > -1) {
        var route = prev[idx];
        route.themeColor = value.themeColor;
        route.title = value.title;
        route.closable = value.closable;
        return [].concat(prev);
      }

      return [].concat(prev, [value]);
    });
  };

  return {
    routes: routes,
    themeColor: themeColor,
    setRoutesOverwrite: setRoutesOverwrite,
    pushRoute: pushRoute,
    changeTheme: changeTheme
  };
};

function CommonTabbar(props) {
  var _context$routes;

  var navigate = reactRouterDom.useNavigate();
  var context = React.useContext(props.context);

  var onClose = function onClose(route, active) {
    var idx = context.routes.findIndex(function (item) {
      return item === route;
    });
    var res = context.routes.filter(function (item) {
      return item !== route;
    }) || [];
    context.setRoutesOverwrite(res);
    if (!active) return;
    if (res.length <= 0) return;
    if (idx >= res.length) idx = res.length - 1;
    if (idx < 0) idx = 0;
    navigate(res[idx].url, {
      replace: true
    });
  };

  var scrollHorizontally = React.useCallback(function (e) {
    e.stopPropagation();
    var ele = document.getElementById(props.id);
    var delta = e.deltaX || e.deltaY;
    ele.scrollLeft += delta * 2;
  }, []);
  return React__default.createElement("div", {
    className: "tn-common-tabbar-container",
    style: {
      maxWidth: "" + props.maxWidth
    },
    id: props.id,
    onMouseEnter: function onMouseEnter(_) {
      return document.addEventListener("wheel", scrollHorizontally);
    },
    onMouseLeave: function onMouseLeave(_) {
      document.removeEventListener('wheel', scrollHorizontally);
    }
  }, React__default.createElement("div", {
    className: "scrollable"
  }, (_context$routes = context.routes) == null ? void 0 : _context$routes.map(function (route) {
    return React__default.createElement(TabItemLink, {
      key: route.url,
      tabRoute: route,
      theme: context.themeColor,
      onClose: onClose,
      tabInPage: props.tabInpage
    });
  })));
}

CommonTabbar.defaultProps = {
  name: "tab-scrollable",
  tabInpage: 0
};

var MOUSE = {
  LEFT: 0,
  MIDDLE: 1,
  RIGHT: 2
};

function ContextMenuFC(props) {
  var _useState = React.useState(null),
      container = _useState[0],
      setContainer = _useState[1];

  var _useState2 = React.useState(),
      bottom = _useState2[0],
      setBottom = _useState2[1];

  var _useState3 = React.useState(),
      right = _useState3[0],
      setRight = _useState3[1];

  var ref = React.useRef();
  React.useEffect(function () {
    document.addEventListener('keydown', onKeyup);

    if (props.forceRender) {
      var _container = document.createElement('div');

      setContainer(_container);
      document.body.appendChild(_container);
    }

    return function () {
      var _container2, _container2$parentEle;

      (_container2 = container) == null ? void 0 : (_container2$parentEle = _container2.parentElement) == null ? void 0 : _container2$parentEle.removeChild(container);
      document.removeEventListener('keydown', onKeyup);
    };
  }, []);

  var onKeyup = function onKeyup(event) {
    var keyCode = event.keyCode;

    if (keyCode === 27) {
      //escape
      if (props.onEscape) {
        props.onEscape();
      }
    }
  };

  React.useEffect(function () {
    // if (props.forceRender) return;
    if (!!props.visible) {
      if (container == null) {
        container = document.createElement('div');
        setContainer(container);
      }

      document.body.appendChild(container);
    }

    if (!props.visible && !props.forceRender) {
      var _container3;

      (_container3 = container) == null ? void 0 : _container3.parentElement.removeChild(container);
      setContainer(null);
    }
  }, [props.visible]);
  React.useEffect(function () {
    if (!ref.current) return;
    var clientH = document.body.clientHeight;

    if (props.autoAdjust && ref.current.clientHeight + props.top > clientH) {
      setBottom(clientH - props.top);
    } else {
      setBottom(null);
    } // right


    var clientW = document.body.clientWidth;

    if (props.autoAdjust && props.left + ref.current.clientWidth > clientW) {
      setRight(0);
    } else {
      setRight(null);
    }
  }, [props.visible, container]);

  var onClick = function onClick(e) {
    if (e.button === MOUSE.LEFT) {
      if (checkClickInBound(e)) return;

      if (props.onCancel) {
        props.onCancel();
      }
    }
  };

  var onRightClick = function onRightClick(e) {
    if (props.onRightClick) {
      e.preventDefault();
      props.onRightClick(e);
    } else if (props.onCancel) {
      e.preventDefault();
      props.onCancel();
    }
  };

  var checkClickInBound = function checkClickInBound(e) {
    var _ref$current;

    var bound = (_ref$current = ref.current) == null ? void 0 : _ref$current.getBoundingClientRect();
    if (!bound) return false;
    var x = e.clientX;
    var y = e.clientY;
    return x > bound.left && x < bound.right && y > bound.top && y < bound.bottom;
  };

  var modal = React__default.createElement("div", {
    className: classNames({
      'context-menu-container': true,
      'visible': props.visible,
      'mask': props.mask
    }),
    onClick: onClick,
    onContextMenu: function onContextMenu(e) {
      return onRightClick(e);
    },
    style: props.maskStyle
  }, React__default.createElement("div", {
    className: "context-menu-wrapper " + (props.wrapperClassname || ''),
    ref: ref,
    style: {
      left: right == null ? props.left : null,
      top: bottom == null ? props.top : null,
      bottom: bottom,
      right: right,
      width: props.width
    }
  }, props.children));
  return (props.visible || props.forceRender) && container && ReactDOM.createPortal(!!props.modalRender ? props.modalRender(modal) : modal, container);
}

ContextMenuFC.defaultProps = {
  mask: true,
  forceRender: false,
  left: 0,
  top: 0,
  autoAdjust: true
};

var MOUSE$1 = {
  LEFT: 0,
  MIDDLE: 1,
  RIGHT: 2
};

var ContextMenuModal = /*#__PURE__*/function (_Component) {
  _inheritsLoose(ContextMenuModal, _Component);

  function ContextMenuModal() {
    var _this;

    _this = _Component.apply(this, arguments) || this;
    _this.ref = React__default.createRef();
    _this.state = {
      container: null
    };

    _this.onClick = function (event) {
      if (event.button === MOUSE$1.LEFT) {
        if (_this.checkClickInBound(event)) return;

        if (_this.props.onCancel) {
          _this.props.onCancel();
        }
      }
    };

    _this.onRightClick = function (event) {
      event.preventDefault();

      if (_this.props.onRightClick) {
        _this.props.onRightClick();
      }
    };

    _this.checkClickInBound = function (event) {
      var _this$ref, _this$ref$current;

      var bound = (_this$ref = _this.ref) == null ? void 0 : (_this$ref$current = _this$ref.current) == null ? void 0 : _this$ref$current.getBoundingClientRect();
      if (!bound) return false;
      var x = event.clientX;
      var y = event.clientY;
      return x > bound.left && x < bound.right && y > bound.top && y < bound.bottom;
    };

    _this.onKeyup = function (event) {
      var keyCode = event.keyCode;

      if (keyCode === 27) {
        //escape
        if (_this.props.onEscape) {
          _this.props.onEscape();
        }
      }
    };

    return _this;
  }

  var _proto = ContextMenuModal.prototype;

  _proto.componentDidMount = function componentDidMount() {
    document.addEventListener('keydown', this.onKeyup);

    if (this.props.forceRender) {
      var container = document.createElement('div');
      this.setState({
        container: container
      });
      document.body.appendChild(container);
    }
  };

  _proto.componentDidUpdate = function componentDidUpdate() {
    if (this.props.forceRender) return;

    if (this.props.visible !== this.visible && !!this.props.visible) {
      this.visible = this.props.visible;
      var container = document.createElement('div'); // container.classList.add('context-menu-container')
      // container.addEventListener('click', this.onCancel)

      this.setState({
        container: container
      });
      document.body.appendChild(container); // ReactDOM.createPortal(this.props.children, this.container);
    } else if (!this.props.visible && this.state.container) {
      this.visible = this.props.visible;
      this.state.container.parentElement.removeChild(this.state.container); // this.state.container.removeEventListener('click', this.onCancel);

      this.setState({
        container: null
      });
    }
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    if (this.state.container) {
      this.state.container.parentElement.removeChild(this.state.container); // this.state.container.removeEventListener('click', this.onCancel);
    }

    document.removeEventListener('keyup', this.onKeyup);
  };

  _proto.render = function render() {
    if (this.props.forceRender) {
      return this.state.container && ReactDOM.createPortal(React__default.createElement("div", {
        className: classNames({
          'context-menu-container': true,
          'mask': this.props.mask,
          'renderVisible': this.props.visible
        }),
        onClick: this.onClick,
        onContextMenu: this.onRightClick
      }, React__default.createElement("div", {
        className: "context-menu-wrapper " + (this.props.wrapperClassname || ''),
        ref: this.ref,
        style: {
          left: this.props.left,
          top: this.props.top,
          bottom: this.props.bottom,
          right: this.props.right,
          width: this.props.width
        }
      }, this.props.children)), this.state.container);
    }

    return this.props.visible && this.state.container && ReactDOM.createPortal(React__default.createElement("div", {
      className: classNames({
        'context-menu-container': true,
        'visible': true,
        'mask': this.props.mask
      }),
      onClick: this.onClick,
      onContextMenu: this.onRightClick
    }, React__default.createElement("div", {
      className: "context-menu-wrapper " + (this.props.wrapperClassname || ''),
      ref: this.ref,
      style: {
        left: this.props.left,
        top: this.props.top,
        bottom: this.props.bottom,
        right: this.props.right,
        width: this.props.width
      }
    }, this.props.children)), this.state.container);
  };

  return ContextMenuModal;
}(React.Component);
ContextMenuModal.defaultProps = {
  mask: true,
  forceRender: false
};

function ContextMenuWrapper(props) {
  // const [height, setHeight] = useState(300);
  var _useState = React.useState(0),
      left = _useState[0],
      setLeft = _useState[1];

  var _useState2 = React.useState(0),
      top = _useState2[0],
      setTop = _useState2[1];

  var _useState3 = React.useState(false),
      visible = _useState3[0],
      setVisible = _useState3[1];

  var ref = React.useRef();
  var childrenRef = React.useRef();
  var width = props.width;

  var onTrigger = function onTrigger() {
    if (props.disabled) return;

    if (props.onVisibleChange) {
      if (props.visible != null) {
        props.onVisibleChange(!props.visible);
      } else {
        props.onVisibleChange(!visible);
        setVisible(!visible);
      }
    } else {
      setVisible(!visible);
    }
  };

  React.useEffect(function () {
    var ele = ref.current;
    if (ele == null) return;
    var bound = ele.getBoundingClientRect();
    var clientX = bound.left + bound.width / 2 - width / 2;
    var bodyW = document.body.clientWidth;

    if (clientX + width > bodyW) {
      clientX = bound.right - width;
    }

    setLeft(clientX);
    var clientY = bound.bottom;
    var bodyH = document.body.clientHeight; // if (!!childrenRef.current) {
    //     let height = childrenRef.current.getBoundingClientRect().height;
    //     if (clientY + height > bodyH) {
    //         clientY = bound.top - height;
    //     }
    // }

    var height = props.height;

    if (clientY + height > bodyH) {
      clientY = bound.top - height - 6;
    } else {
      clientY += 6;
    }

    setTop(clientY);
  }, [props.visible, visible]);
  return React__default.createElement("div", {
    ref: ref
  }, React__default.createElement("div", {
    onClick: onTrigger
  }, props.container), React__default.createElement(ContextMenuFC, {
    visible: props.visible == null ? visible : props.visible,
    left: left,
    top: top,
    width: width,
    wrapperClassname: "tn-context-menu-wrapper " + (props.wrapperClassname || ''),
    onCancel: props.closable ? onTrigger : null,
    maskStyle: props.maskStyle
  }, React__default.createElement("div", {
    ref: childrenRef,
    style: {
      maxHeight: (props.height || 300) + "px",
      height: props.height != null ? props.height + "px" : null,
      overflow: 'auto'
    }
  }, props.children)));
}

ContextMenuWrapper.defaultProps = {
  width: 250,
  closable: true
};

var _excluded = ["children", "className", "onItemDrop", "accept", "style", "canDrop", "canDrag", "nodeType", "dragType", "value"];

function DroppableWrapper(_ref) {
  var children = _ref.children,
      className = _ref.className,
      onItemDrop = _ref.onItemDrop,
      accept = _ref.accept,
      style = _ref.style,
      _canDrop = _ref.canDrop,
      _canDrag = _ref.canDrag,
      nodeType = _ref.nodeType,
      dragType = _ref.dragType,
      value = _ref.value,
      restProps = _objectWithoutPropertiesLoose(_ref, _excluded);

  var ref = React__default.useRef();

  var _useDrag = reactDnd.useDrag({
    type: dragType || 'default',
    item: value,
    collect: function collect(monitor) {
      return {
        isDragging: !!monitor.isDragging()
      };
    },
    canDrag: function canDrag(_) {
      return _canDrag;
    }
  }),
      isDragging = _useDrag[0].isDragging,
      drager = _useDrag[1];

  var _useDrop = reactDnd.useDrop({
    accept: accept || 'default',
    collect: function collect(monitor) {
      monitor.getItem();
      return {
        isOver: monitor.isOver()
      };
    },
    canDrop: function canDrop(monitor) {
      if (_canDrop != null) return _canDrop;
      return monitor.canDrop();
    },
    drop: function drop(item) {
      if (onItemDrop) {
        onItemDrop(item);
      }
    }
  }),
      collectProps = _useDrop[0],
      droper = _useDrop[1];

  droper(drager(ref));

  if (nodeType === 'tr') {
    return React__default.createElement("tr", Object.assign({
      ref: ref,
      className: className + " " + classNames({
        'will-drop': collectProps.isOver && _canDrop,
        'can-drag': _canDrag,
        'droppable-wrapper-tr': true
      }),
      style: {
        cursor: 'move',
        opacity: isDragging ? 0.5 : 1
      }
    }, restProps), children);
  }

  if (nodeType === 'default') {
    return React__default.createElement("div", Object.assign({
      ref: ref,
      style: style,
      className: classNames(className, {
        'will-drop': collectProps.isOver && _canDrop,
        'droppable-wrapper': true,
        'can-drag': _canDrag
      })
    }, restProps), children);
  }

  return null;
}

DroppableWrapper.defaultProps = {
  canDrop: true
};

var _excluded$1 = ["index"],
    _excluded2 = ["editable", "cellKey", "selectedKey", "children", "dataIndex", "record", "align", "type", "options", "allowClear", "showSelectSearch", "directEdit", "handleSave", "pressEnter", "pressTab", "onTap", "onRightTap"];
var Option = antd.Select.Option;
var EditableContext = /*#__PURE__*/React__default.createContext(null);
var EditableRow = function EditableRow(_ref) {
  var props = _objectWithoutPropertiesLoose(_ref, _excluded$1);

  var _Form$useForm = antd.Form.useForm(),
      form = _Form$useForm[0];

  return React__default.createElement(antd.Form, {
    form: form,
    component: false,
    autoComplete: "off"
  }, React__default.createElement(EditableContext.Provider, {
    value: form
  }, React__default.createElement("tr", Object.assign({}, props))));
};
var EditableCell = function EditableCell(_ref2) {
  var editable = _ref2.editable,
      cellKey = _ref2.cellKey,
      selectedKey = _ref2.selectedKey,
      children = _ref2.children,
      dataIndex = _ref2.dataIndex,
      record = _ref2.record,
      align = _ref2.align,
      type = _ref2.type,
      options = _ref2.options,
      allowClear = _ref2.allowClear,
      showSelectSearch = _ref2.showSelectSearch,
      directEdit = _ref2.directEdit,
      handleSave = _ref2.handleSave,
      pressEnter = _ref2.pressEnter,
      pressTab = _ref2.pressTab,
      onTap = _ref2.onTap,
      onRightTap = _ref2.onRightTap,
      restProps = _objectWithoutPropertiesLoose(_ref2, _excluded2);

  var _useState = React.useState(false),
      editing = _useState[0],
      setEditing = _useState[1];

  var inputRef = React.useRef(null);
  var selectRef = React.useRef();
  var form = React.useContext(EditableContext);
  var divRef = React.useRef();
  React.useEffect(function () {
    if (!!cellKey && cellKey === selectedKey) {
      var _divRef$current;

      (_divRef$current = divRef.current) == null ? void 0 : _divRef$current.focus();
    }
  }, [selectedKey]);
  React.useEffect(function () {
    if (editing) {
      var _inputRef$current, _selectRef$current;

      (_inputRef$current = inputRef.current) == null ? void 0 : _inputRef$current.focus({
        cursor: 'end'
      });
      (_selectRef$current = selectRef.current) == null ? void 0 : _selectRef$current.focus();
    }
  }, [editing]);

  var onKeydown = function onKeydown(e) {
    var keyCode = e.key;
    if (editing) return;

    if (keyCode.length === 1 && keyCode.match(/[a-zA-Z0-9\w\W]/i)) {
      if (!!cellKey && cellKey === selectedKey) {
        toggleEdit(); // divRef.current?.removeEventListener('keydown', onKeydown)
      }
    }

    if (e.key === 'Enter' && !!pressEnter) {
      pressEnter(record); // divRef.current?.removeEventListener('keydown', onKeydown)
    }

    if (e.key === 'Tab' && !!pressTab) {
      e.preventDefault();
      setTimeout(function () {
        pressTab(record);
      }, 0); // divRef.current?.removeEventListener('keydown', onKeydown)
    }
  };

  var onKeyPress = function onKeyPress(e) {
    // if (type === 'TextArea' && e.ctrlKey && e.keyCode === 13) {
    //     onPressEnter();
    // } else if (type === 'TextArea' && e.keyCode === 13) {
    //     // inputRef.current?.blur();
    // }
    if (e.key === 'Escape') {
      // esc
      toggleEdit();
      setTimeout(function () {
        var _divRef$current2;

        (_divRef$current2 = divRef.current) == null ? void 0 : _divRef$current2.focus();
      }, 1);
    }

    if (e.key === 'Tab') {
      e.preventDefault();
      setTimeout(function () {
        if (!!pressTab) {
          pressTab(record);
        }

        save();
      }, 0);
    }

    if (e.key === 'Enter') {
      e.preventDefault();
      setTimeout(function () {
        onPressEnter();
      }, 0);
    }
  };

  var toggleEdit = function toggleEdit() {
    var _form$setFieldsValue;

    setEditing(!editing);
    form.setFieldsValue((_form$setFieldsValue = {}, _form$setFieldsValue[dataIndex] = record[dataIndex], _form$setFieldsValue));
  };

  var onPressEnter = /*#__PURE__*/function () {
    var _ref3 = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee() {
      var values;
      return runtime_1.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.prev = 0;
              _context.next = 3;
              return form.validateFields();

            case 3:
              values = _context.sent;
              toggleEdit();

              if (!!handleSave) {
                handleSave(_extends({}, record, values));
              }

              if (!!pressEnter) {
                pressEnter(_extends({}, record, values));
              }

              _context.next = 13;
              break;

            case 9:
              _context.prev = 9;
              _context.t0 = _context["catch"](0);
              console.log('Save failed:', _context.t0);
              toggleEdit();

            case 13:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, null, [[0, 9]]);
    }));

    return function onPressEnter() {
      return _ref3.apply(this, arguments);
    };
  }();

  var save = /*#__PURE__*/function () {
    var _ref4 = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee2() {
      var values;
      return runtime_1.wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              _context2.prev = 0;
              _context2.next = 3;
              return form.validateFields();

            case 3:
              values = _context2.sent;
              toggleEdit();

              if (!!handleSave) {
                handleSave(_extends({}, record, values));
              }

              _context2.next = 11;
              break;

            case 8:
              _context2.prev = 8;
              _context2.t0 = _context2["catch"](0);
              console.log('Save failed:', _context2.t0);

            case 11:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2, null, [[0, 8]]);
    }));

    return function save() {
      return _ref4.apply(this, arguments);
    };
  }();

  var selectSave = /*#__PURE__*/function () {
    var _ref5 = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee3(_) {
      var values;
      return runtime_1.wrap(function _callee3$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              _context3.prev = 0;
              _context3.next = 3;
              return form.validateFields();

            case 3:
              values = _context3.sent;
              toggleEdit();
              handleSave(_extends({}, record, values)); // if (onSelectChange) {
              //     onSelectChange(e);
              // }

              _context3.next = 11;
              break;

            case 8:
              _context3.prev = 8;
              _context3.t0 = _context3["catch"](0);
              console.log('Save failed:', _context3.t0);

            case 11:
            case "end":
              return _context3.stop();
          }
        }
      }, _callee3, null, [[0, 8]]);
    }));

    return function selectSave(_x) {
      return _ref5.apply(this, arguments);
    };
  }();

  var singleClick = function singleClick() {
    if (!directEdit) {
      return;
    }

    toggleEdit();
  };

  var childNode = children;

  var cellEditChildren = function cellEditChildren() {
    if (type === 'Select') {
      return React__default.createElement(antd.Select, {
        ref: selectRef,
        onBlur: toggleEdit,
        onKeyDown: onKeyPress,
        onChange: selectSave,
        showSearch: showSelectSearch || false,
        optionFilterProp: "label",
        size: "small",
        allowClear: allowClear,
        bordered: false,
        className: "editable-select",
        filterOption: function filterOption(input, option) {
          return option.children.toLowerCase().includes(input.toLowerCase());
        }
      }, options.map(function (item, idx) {
        return React__default.createElement(Option, {
          value: item.value,
          key: idx,
          label: item.label
        }, item.label);
      }));
    } else if (type === 'InputNumberPrice') {
      return React__default.createElement(antd.InputNumber, {
        onPressEnter: onPressEnter,
        onBlur: save,
        onKeyDown: onKeyPress,
        bordered: false,
        formatter: function formatter(value) {
          return ("\uFFE5 " + value).replace(/\B(?=(\d{3})+(?!\d))/g, ',');
        },
        parser: function parser(value) {
          return value.replace(/\￥\s?|(,*)/g, '');
        }
      });
    } else if (type === 'InputNumber') {
      return React__default.createElement(antd.InputNumber, {
        min: 1,
        max: 99999,
        onPressEnter: onPressEnter,
        onBlur: save,
        onKeyDown: onKeyPress,
        bordered: false
      });
    } else if (type === 'InputNumberPercent') {
      return React__default.createElement(antd.InputNumber, {
        min: 0,
        max: 100,
        onPressEnter: onPressEnter,
        onBlur: save,
        onKeyDown: onKeyPress,
        formatter: function formatter(value) {
          return value + "%";
        },
        bordered: false
      });
    } else if (type === 'TextArea') {
      return React__default.createElement(antd.Input.TextArea, {
        ref: inputRef,
        onBlur: save,
        bordered: false,
        onKeyDown: onKeyPress,
        autoSize: {
          minRows: 1
        }
      });
    } else {
      return React__default.createElement(antd.Input, {
        ref: inputRef,
        size: "small",
        onBlur: save,
        onKeyDown: onKeyPress,
        bordered: false,
        autoComplete: "off"
      });
    }
  };

  if (editable) {
    childNode = editing ? React__default.createElement("div", {
      className: classNames({
        "editable-cell-value-input": true,
        // "active": cellKey === selectedKey,
        "align-right": align === 'right'
      })
    }, React__default.createElement(antd.Form.Item, {
      style: {
        margin: 0
      },
      name: dataIndex
    }, cellEditChildren())) : React__default.createElement("div", {
      className: classNames({
        "editable-cell-value-wrap": true,
        // "active": cellKey === selectedKey,
        "align-right": align === 'right'
      }),
      style: {
        minHeight: '24px',
        outline: 'none'
      },
      onClick: singleClick,
      onDoubleClick: toggleEdit,
      contentEditable: "false",
      suppressContentEditableWarning: true,
      tabIndex: -1,
      ref: divRef,
      onKeyDown: function onKeyDown(e) {
        onKeydown(e);
      }
    }, children);
  }

  return React__default.createElement("td", Object.assign({}, restProps, {
    onContextMenu: function onContextMenu(e) {
      if (onRightTap) onRightTap(e, record, cellKey);
    },
    onClick: function onClick() {
      if (onTap) onTap(record, cellKey);
    }
  }), childNode, !!cellKey && cellKey === selectedKey && React__default.createElement(React.Fragment, null, React__default.createElement("div", {
    className: "active-border-top",
    style: {
      backgroundColor: !editable ? '#999' : null
    }
  }), React__default.createElement("div", {
    className: "active-border-bottom",
    style: {
      backgroundColor: !editable ? '#999' : null
    }
  }), React__default.createElement("div", {
    className: "active-border-left",
    style: {
      backgroundColor: !editable ? '#999' : null
    }
  }), React__default.createElement("div", {
    className: "active-border-right",
    style: {
      backgroundColor: !editable ? '#999' : null
    }
  })));
};

function s2ab(s) {
  var buf = new ArrayBuffer(s.length);
  var view = new Uint8Array(buf);

  for (var i = 0; i != s.length; ++i) {
    view[i] = s.charCodeAt(i) & 0xFF;
  }

  return buf;
}

function ExportDataToXlsx(props) {
  var _useState = React.useState(false),
      loading = _useState[0],
      setLoading = _useState[1];

  React.useEffect(function () {}, [loading]);

  var handleExportData = function handleExportData() {
    //创建xlsx工作簿
    var workbook = XLSX.utils.book_new();

    if (props.data) {
      setLoading(true);
      Object.keys(props.data).forEach(function (sheetName) {
        //为工作簿中添加工作表
        var workSheet = XLSX.utils.aoa_to_sheet(props.data[sheetName]);
        XLSX.utils.book_append_sheet(workbook, workSheet, sheetName);
      }); //将工作簿转化为二进制文件blob类型

      var wopts = {
        bookType: 'xlsx',
        bookSST: false,
        type: 'binary' // 二进制文件

      };
      var wbout = XLSX.write(workbook, wopts);
      var blob = new Blob([s2ab(wbout)], {
        type: "application/octet-stream"
      }); //下载blob的过程

      var link = document.createElement('a');
      link.setAttribute('href', window.URL.createObjectURL(blob));
      link.setAttribute('download', props.fileName + ".xlsx");
      link.style.visibility = 'hidden';
      document.body.appendChild(link);
      link.click();
      document.body.removeChild(link);
      setLoading(false);
    } else {
      antd.message.warning("导出数据未指定");
    }
  };

  return React__default.createElement(antd.Button, {
    size: "small",
    loading: loading,
    style: props.style,
    onClick: handleExportData
  }, props.buttonName ? props.buttonName : "导出xlsx数据");
}

function ImportDataFromXlsx(props) {
  var _useState = React.useState(false),
      loading = _useState[0],
      setLoading = _useState[1];

  React.useEffect(function () {}, [loading]);

  var handleImportData = function handleImportData(info) {
    setLoading(true);
    var files = info.file; // 获取文件名称

    var name = files.name; // 获取文件后缀

    var suffix = name.substr(name.lastIndexOf("."));
    var reader = new FileReader();

    reader.onload = function (event) {
      try {
        // 判断文件类型是否正确
        if (".xls" != suffix && ".xlsx" != suffix) {
          antd.message.error("选择Excel格式的文件导入!");
          return false;
        }

        var result = event.target.result;
        var workSheet = XLSX.read(result, {
          type: 'binary'
        });
        var parsedWorkbook = Object.keys(workSheet.Sheets).map(function (name) {
          var sheet = workSheet.Sheets[name];
          return {
            name: name,
            data: XLSX.utils.sheet_to_json(sheet, {
              header: 1
            })
          };
        });

        if (props.onComplete && parsedWorkbook) {
          props.onComplete(parsedWorkbook);
        }

        return true;
      } catch (e) {
        console.log(e);
        antd.message.error("导入失败");
        return false;
      } finally {
        setLoading(false);
      }
    };

    reader.readAsBinaryString(files);
  };

  return React__default.createElement(antd.Upload, {
    accept: '.xlsx',
    showUploadList: false,
    customRequest: handleImportData
  }, React__default.createElement(antd.Button, {
    size: "small",
    loading: loading,
    style: props.style
  }, props.buttonName ? props.buttonName : "导入xlsx数据"));
}

var MultiTagSelect = function MultiTagSelect(props) {
  var onTagChange = function onTagChange(checked, tag) {
    if (props.lock) return;

    if (props.single) {
      if (props.onChange) props.onChange(tag);
      return;
    }

    var tags = props.tags;
    var data = tags.filter(function (t) {
      return t !== tag;
    }) || [];
    if (checked) data.push(tag);
    if (props.onChange) props.onChange(data);
  }; //用于在标签过长的时候可使用鼠标滑轮滑动


  var onMouseOver = function onMouseOver() {
    var tags = document.querySelector('.tn-multi-tag-select-container');
    tags.addEventListener('wheel', function (event) {
      event.preventDefault();
      tags.scrollLeft += event.deltaY;
    });
  };

  return React__default.createElement("div", {
    className: "tn-multi-tag-select-container",
    onMouseOver: onMouseOver,
    style: props.style || null
  }, props.params && React__default.createElement("div", {
    className: "tag-group",
    style: {
      gap: props.spaceSize != null ? props.spaceSize : 10
    }
  }, props.params.map(function (param, idx) {
    var _param$backgroundColo;

    var tagChecked;

    if (typeof props.tags === 'number') {
      tagChecked = props.tags === param.tag;
    } else {
      var _props$tags;

      tagChecked = ((_props$tags = props.tags) == null ? void 0 : _props$tags.indexOf(param.tag)) > -1;
    }

    if (props.showChecked && !tagChecked) return null;
    var color = param.color ? param.color : ((_param$backgroundColo = param.backgroundColor) == null ? void 0 : _param$backgroundColo.indexOf('#')) > -1 ? 'white' : null;
    if (tagChecked) return React__default.createElement(antd.Tag, {
      key: idx,
      className: "multi-tag multi-tag-checked",
      onClick: function onClick() {
        return onTagChange(false, param.tag);
      },
      style: {
        'color': color
      },
      color: param.backgroundColor ? param.backgroundColor : props.themeColor || '#108ee9'
    }, param.name);
    return React__default.createElement(antd.Tag, {
      className: "multi-tag",
      key: idx,
      onClick: function onClick() {
        return onTagChange(true, param.tag);
      }
    }, param.name);
  })), props.paramGroups && React__default.createElement("div", null, props.paramGroups.map(function (params, idx) {
    return React__default.createElement("div", {
      className: "tag-group multi",
      key: idx,
      style: {
        gap: props.spaceSize != null ? props.spaceSize : 10
      }
    }, params.map(function (param, idx) {
      var _param$backgroundColo2;

      var tagChecked;

      if (typeof props.tags === 'number') {
        tagChecked = props.tags === param.tag;
      } else {
        var _props$tags2;

        tagChecked = ((_props$tags2 = props.tags) == null ? void 0 : _props$tags2.indexOf(param.tag)) > -1;
      }

      if (props.showChecked && !tagChecked) return null;
      var color = param.color ? param.color : ((_param$backgroundColo2 = param.backgroundColor) == null ? void 0 : _param$backgroundColo2.indexOf('#')) > -1 ? 'white' : null;
      if (tagChecked) return React__default.createElement(antd.Tag, {
        key: idx,
        className: "multi-tag multi-tag-checked",
        onClick: function onClick() {
          return onTagChange(false, param.tag);
        },
        style: {
          'color': color
        },
        color: param.backgroundColor ? param.backgroundColor : props.themeColor || '#108ee9'
      }, param.name);
      return React__default.createElement(antd.Tag, {
        className: "multi-tag",
        key: idx,
        onClick: function onClick() {
          return onTagChange(true, param.tag);
        }
      }, param.name);
    }));
  })));
};

MultiTagSelect.defaultProps = {
  tags: [],
  params: [],
  single: false
};

function VerticalResizer(props) {
  var ref = React.useRef();
  var containerRef = React.useRef();
  React.useEffect(function () {
    var dom = ref.current;

    if (!!dom) {
      dom.addEventListener('pointerdown', onPointerDown);
    }

    var containerDom = containerRef.current;
    containerDom == null ? void 0 : containerDom.getBoundingClientRect(); // let containerRect = containerDom?.getBoundingClientRect();

    containerDom.style.height = (props.defaultHeight || 300) + "px";
    if (props.onHeightChange) props.onHeightChange(props.defaultHeight || 300);
    return function () {
      dom == null ? void 0 : dom.removeEventListener('pointerdown', onPointerDown);
      dom == null ? void 0 : dom.ownerDocument.removeEventListener('pointermove', onPointerMove);
      dom == null ? void 0 : dom.ownerDocument.removeEventListener('pointerup', onPointerUp);
    };
  }, []);
  var onPointerDown = React.useCallback(function (event) {
    if (event.isPrimary === false) return;
    var dom = ref.current;

    if (!dom) {
      console.error('resizer dom not initialize!');
    }
    dom.ownerDocument.addEventListener('pointermove', onPointerMove);
    dom.ownerDocument.addEventListener('pointerup', onPointerUp);
  }, []);
  var onPointerMove = React.useCallback(function (event) {
    if (event.isPrimary === false) return;
    var dom = ref.current;

    if (!dom) {
      console.error('resizer dom not initialize!');
    }
    dom.getBoundingClientRect(); // const rect = dom.getBoundingClientRect();

    var containerDom = containerRef.current;
    var containerRect = containerDom == null ? void 0 : containerDom.getBoundingClientRect();
    var value = containerRect.height - event.movementY;
    containerDom.style.height = value + "px";
    if (props.onHeightChange) props.onHeightChange(value); // const x = (document.body.offsetWidth - rect.right) - event.movementX;
    // dom.style.right = x + 'px';
    // document.getElementById('viewport').style.right = (x + rect.width) + 'px';
    // document.getElementById('sidebar').style.width = (x + rect.width) + 'px';
  }, []);
  var onPointerUp = React.useCallback(function (event) {
    if (event.isPrimary === false) return;
    var dom = ref.current;

    if (!dom) {
      console.error('resizer dom not initialize!');
    }
    if (props.onHeightChangeDown) props.onHeightChangeDown(props.defaultHeight);
    dom.ownerDocument.removeEventListener('pointermove', onPointerMove);
    dom.ownerDocument.removeEventListener('pointerup', onPointerUp);
  }, []);
  return React__default.createElement("div", {
    className: "tn-common-resizer-container",
    ref: containerRef
  }, React__default.createElement("div", {
    className: "resizer-bar",
    style: {
      backgroundColor: props.color || null
    },
    ref: ref
  }), React__default.createElement("div", {
    className: "content"
  }, props.children));
}

var StatsPanel = /*#__PURE__*/function () {
  function StatsPanel(parentId) {
    //parentId： 外部包装监听器的模块的id
    this.add(parentId);
  }

  var _proto = StatsPanel.prototype;

  _proto.add = function add(parentId) {
    var root = document.getElementById(parentId);
    if (!root) return;
    if (this.stats) return;
    var tmpStats = new Stats();
    tmpStats.showPanel(0);
    tmpStats.dom.style.position = 'relative';
    root.appendChild(tmpStats.dom);
    this.stats = tmpStats;
  };

  _proto.update = function update() {
    if (this.stats) {
      this.stats.update();
    }
  };

  return StatsPanel;
}();

/**
 * 用antv/g2封装的折线图组件
 *  具体写法可参考http://antv-2018.alipay.com/zh-cn/g2/3.x/demo/line/curved.html
 *  */
function MultiLineChart(props) {
  var _useState = React.useState(),
      lineChart = _useState[0],
      setLineChart = _useState[1];

  React.useEffect(function () {
    var chart = new g2.Chart({
      container: 'tn-query-multi-container',
      autoFit: true,
      height: props.height || 300,
      padding: [30, 80, 30, 40]
    });
    chart.data(props.q_data);
    chart.tooltip({
      showCrosshairs: true,
      shared: true,
      crosshairs: {
        type: 'xy'
      }
    });
    chart.scale({
      time: {
        type: 'timeCat',
        range: [0, 0.95],
        tickCount: 5,
        alias: '时间',
        mask: 'YYYY-MM-DD '
      },
      value: {
        nice: true,
        formatter: function formatter(val) {
          return "" + val.toFixed(props.precision);
        },
        alias: '数值',
        tickCount: 6
      }
    });
    chart.line().position('time*value').color('name');
    chart.point().position('time*value').color('name').shape('circle').style({
      fillOpacity: 1
    });
    chart.legend({
      position: 'right'
    });
    chart.axis('value', {
      grid: {
        line: {
          style: {
            lineDash: [10, 5],
            lineWidth: 1,
            stroke: '#ccc'
          }
        }
      },
      line: {
        style: {
          lineWidth: 1,
          stroke: '#666'
        }
      }
    });
    chart.axis('time', {
      line: {
        style: {
          lineWidth: 1,
          stroke: '#666'
        }
      }
    }); // this.lineChart = chart;

    setLineChart(chart);
    chart.render();
    return function () {
      chart.clear();
      chart.destroy();
    };
  }, []);
  React.useEffect(function () {
    if (!lineChart) return;
    lineChart.changeData(props.q_data);
  }, [lineChart, props.q_data]);
  React.useEffect(function () {
    if (!lineChart) return; // lineChart.height = props.height;

    var ele = document.getElementById('tn-query-multi-container');
    lineChart.changeSize(ele == null ? void 0 : ele.clientWidth, props.height); // lineChart.changeData(props.q_data);
  }, [props.height]);
  return React__default.createElement("div", {
    id: "tn-query-multi-container"
  });
}

/**
 * 用echarts封装的x轴为时间轴的组件
 * echarts中option的具体配置法详见：   https://echarts.apache.org/zh/option.html
 *  */
function MultiEChart(props) {
  var uuid = genUUID();

  var _useState = React.useState(),
      showChart = _useState[0],
      setShowChart = _useState[1];

  React.useEffect(function () {
    var tmpChart = echarts.init(document.getElementById(uuid));
    tmpChart.resize({
      height: props.height,
      width: props.width
    });
    tmpChart.setOption(generateOption());
    setShowChart(tmpChart);
  }, []);
  React.useEffect(function () {
    if (showChart) {
      showChart.setOption(generateOption());
    }
  }, [props.q_data]);
  React.useEffect(function () {
    if (showChart) {
      if (props.width) {
        showChart.resize({
          height: props.height,
          width: props.width
        });
      } else {
        showChart.resize({
          height: props.height,
          width: document.body.clientWidth
        });
      }
    }
  }, [props.height, props.width]);
  React.useEffect(function () {}, [showChart]);

  var generateOption = function generateOption() {
    var dimensions_set = new Set();
    var source_dict = {};
    var label_count = 0;
    props.q_data.forEach(function (datePoint) {
      if (source_dict.hasOwnProperty(datePoint.time)) {
        source_dict[datePoint.time][datePoint.name] = datePoint.value.toFixed(props.precision);
      } else {
        label_count++;
        source_dict[datePoint.time] = {
          time: datePoint.time
        };
        source_dict[datePoint.time][datePoint.name] = datePoint.value.toFixed(props.precision);
      }

      if (!dimensions_set.has(datePoint.name)) {
        dimensions_set.add(datePoint.name);
      }
    });
    var series = [];
    dimensions_set.forEach(function (name) {
      if (props.type === 'line') {
        series.push({
          name: name,
          connectNulls: true,
          type: props.type,
          encode: {
            x: "time",
            y: name
          }
        });
      } else {
        series.push({
          name: name,
          barGap: "0%",
          type: props.type,
          encode: {
            x: "time",
            y: name
          }
        });
      }
    });
    return {
      legend: {
        top: "2.5%",
        right: "2%",
        orient: "horizontal",
        itemGap: 25
      },
      grid: props.padding,
      dataset: {
        source: Object.values(source_dict)
      },
      xAxis: {
        type: 'time',
        minInterval: 3600 * 24 * 1000,
        // splitLine: {
        //     show: false,
        // },
        // boundaryGap:true,
        boundaryGap: ['10%', '40%'],
        axisTick: {
          alignWithLabel: true
        },
        splitNumber: label_count
      },
      yAxis: {
        type: 'value'
      },
      tooltip: {
        trigger: 'axis',
        axisPointer: {
          type: "shadow"
        }
      },
      series: series
    };
  };

  return React__default.createElement("div", {
    className: 'line-charts-echart',
    id: uuid
  });
}
MultiEChart.defaultProps = {
  q_data: [],
  precision: 0,
  height: 250,
  type: "line",
  padding: {}
};

function UploadDragger(_ref) {
  var children = _ref.children,
      className = _ref.className,
      onFileDrop = _ref.onFileDrop,
      _onContextMenu = _ref.onContextMenu,
      disabled = _ref.disabled;

  var _useState = React.useState(false),
      onFileDragOver = _useState[0],
      setOnFileDragOver = _useState[1]; // 拖拽进入的文件或文件夹列表，待处理


  var _useState2 = React.useState(),
      dataTransferItems = _useState2[0],
      setDataTransferItems = _useState2[1]; // 拖拽上传时 维持住上锁，等待所有文件处理完后一起给上传组件


  var _useState3 = React.useState(false),
      uploadMaintainLock = _useState3[0],
      setUploadMaintainLock = _useState3[1]; // 拖拽上传时异步分批处理完的文件存在这里，全部处理完后统一传给uploadfilelist


  var _useState4 = React.useState([]),
      dropUploadFileList = _useState4[0],
      setDropUploadFileList = _useState4[1];

  var _useState5 = React.useState([]),
      dropFolderList = _useState5[0],
      setDropFolderList = _useState5[1];

  var _useState6 = React.useState(0),
      fileCounter = _useState6[0],
      setFileCounter = _useState6[1];

  var _useState7 = React.useState(0),
      folderCounter = _useState7[0],
      setFolderCounter = _useState7[1]; ///// 拖拽上传


  var loadingIndicatorHide;
  React.useEffect(function () {
    if (!uploadMaintainLock) return;
    if (dataTransferItems == null) return; // 上锁并且拽入文件后开始处理

    loadingIndicatorHide = antd.message.loading('正在解析文件...', 0);
    setTimeout(loadingIndicatorHide, 500);
    onDrop();
  }, [dataTransferItems, uploadMaintainLock]);
  React.useEffect(function () {
    // 处理完解析文件 解锁后，开启上传，等同于 beforeUpload
    if (dropUploadFileList.length === 0 && dropFolderList.length === 0) return;

    if (!uploadMaintainLock) {
      if (onFileDrop) {
        onFileDrop(dropUploadFileList, dropFolderList, fileCounter, folderCounter);
      } // setUploadFileList(dropUploadFileList);


      setDropUploadFileList([]);
      setDropFolderList([]);
      setFileCounter(0);
      setFolderCounter(0);
    }
  }, [uploadMaintainLock]);

  var onDrop = function onDrop() {
    var items = dataTransferItems;
    var length = items.length;

    for (var i = 0; i < length; i++) {
      var entry = items[i].webkitGetAsEntry();
      traverseFileTree(entry);
    }
  };

  var uploadMaintainTimer$;

  var traverseFileTree = function traverseFileTree(item, path, folderKey) {
    if (path === void 0) {
      path = "";
    }

    if (folderKey === void 0) {
      folderKey = '';
    }

    clearTimeout(uploadMaintainTimer$);
    path = path || "";

    if (item != null && item.isFile) {
      var fileItem = item; // let fileItem: FileSystemFileEntry = item;

      setFileCounter(function (pre) {
        return pre + 1;
      });
      fileItem.file(function (file) {
        clearTimeout(uploadMaintainTimer$);
        setDropUploadFileList(function (pre) {
          file['uid'] = genUUID();
          file['parentKey'] = folderKey;
          return [].concat(pre, [file]);
        });
        uploadMaintainTimer$ = setTimeout(function () {
          setUploadMaintainLock(false);
        }, 500);
      });
    } else if (item != null && item.isDirectory) {
      // let directoryItem: FileSystemDirectoryEntry = item;
      var directoryItem = item;
      var dirReader = directoryItem.createReader();
      setFolderCounter(function (pre) {
        return pre + 1;
      });
      var dir = {
        name: directoryItem.name,
        uid: genUUID(),
        parentKey: folderKey
      };
      setDropFolderList(function (pre) {
        return [].concat(pre, [dir]);
      });
      uploadMaintainTimer$ = setTimeout(function () {
        setUploadMaintainLock(false);
      }, 500);
      dirReader.readEntries(function (entries) {
        for (var i = 0; i < entries.length; i++) {
          traverseFileTree(entries[i], path + item.name + "/", dir.uid);
        }
      });
    }
  };

  return React__default.createElement("div", {
    className: classNames(className, {
      'on-drag-over': onFileDragOver,
      'upload-dragger': true
    }),
    onDrop: function onDrop(e) {
      if (disabled) return;
      e.preventDefault(); // e.stopPropagation();

      setOnFileDragOver(false);
      var items = e.dataTransfer.items;
      if (items == null || items.length === 0) return;
      if (items[0].kind !== 'file') return;
      setUploadMaintainLock(true); // 维持住不立即发生上传

      setDataTransferItems(items);
    },
    onDragEnter: function onDragEnter(e) {
      if (disabled) return;
      e.preventDefault(); // e.stopPropagation();

      var items = e.dataTransfer.items;
      if (items == null || items.length === 0) return;
      if (items[0].kind !== 'file') return;
      setOnFileDragOver(true);
    },
    onDragLeave: function onDragLeave(e) {
      if (disabled) return;
      e.preventDefault(); // e.stopPropagation();

      setOnFileDragOver(false);
    },
    onDragOver: function onDragOver(e) {
      if (disabled) return;
      e.preventDefault(); // e.stopPropagation();

      var items = e.dataTransfer.items;
      if (items == null || items.length === 0) return;
      if (items[0].kind !== 'file') return;
      setOnFileDragOver(true);
    },
    onContextMenu: function onContextMenu(e) {
      if (_onContextMenu) _onContextMenu(e);
    }
  }, !disabled && React__default.createElement("div", {
    className: 'drag-over-layer'
  }, "\u62D6\u62FD\u5230\u6B64\u533A\u57DF\u4E0A\u4F20"), children);
}

function DownloadButton(props) {
  //引入上下文
  var downloadContext = React.useContext(props.downloadFileContext);
  return React__default.createElement(antd.Button, {
    icon: React__default.createElement(icons.ArrowDownOutlined, null),
    title: props.title,
    size: "small",
    disabled: props.disabled ? true : false,
    onClick: function onClick(e) {
      e.stopPropagation();
      e.preventDefault();
      downloadContext.startDownload(props.files);
    }
  });
}
DownloadButton.defaultProps = {
  title: "下载"
};

function DownloadItem(props) {
  var downloadContext = React.useContext(props.downloadContext);

  var _useState = React.useState(0),
      progress = _useState[0],
      setProgress = _useState[1];

  var _useState2 = React.useState(''),
      msg = _useState2[0],
      setMsg = _useState2[1];

  var xhr = new XMLHttpRequest();
  React.useEffect(function () {
    if (downloadContext.visible) {
      xhr.abort();
      start();
    }
  }, [downloadContext.visible]);

  xhr.onload = function () {
    if (xhr.status === 200) {
      setMsg('下载完毕！'); // resolve(xhr.response)

      downloadFile(xhr.response);
    }
  };

  xhr.onprogress = function (e) {
    var p = Math.round(e.loaded / e.total * 100);
    setProgress(p);
  };

  xhr.onerror = function (e) {
    console.log(e);
    setMsg('发生错误，下载失败');
    props.onComplete();
  };

  var getBlob = function getBlob(url) {
    // const xhr = new XMLHttpRequest();
    xhr.open('GET', url, true);
    xhr.responseType = 'blob';
    xhr.send();
  };

  var start = function start() {
    var file = props.file;

    if (file == null) {
      setMsg('文件信息异常，下载被取消');
      props.onComplete();
      return;
    }

    if (file.url) {
      setMsg("\u5F00\u59CB\u4E0B\u8F7D\uFF1A" + file.filename + (file.suffix || ''));
      getBlob(file.url);
      return;
    } else {
      if (file.bucketName && file.filename && file.objectName && file.suffix && props.getFileUrl) {
        setMsg('正在获取下载链接...');
        props.getFileUrl(file).then(function (res) {
          var url = res.data;

          if (url == null) {
            setMsg('文件不存在或已被清理，下载终止');
            props.onComplete();
            return;
          }

          setMsg("\u5F00\u59CB\u4E0B\u8F7D\uFF1A" + file.filename + (file.suffix || ''));
          getBlob(url);
        }).catch(function (err) {
          console.error(err);
          setMsg('文件不存在或已被清理，下载终止');
          props.onComplete();
        });
      } else {
        antd.message.warning("文件信息不全或api不存在!");
      }
    }
  };

  var downloadFile = function downloadFile(blob) {
    var file = props.file;
    var link = document.createElement("a");
    link.style.display = 'none';
    var href = window.URL.createObjectURL(blob);
    var downloadName = "" + file.filename + (file.suffix || '');
    link.setAttribute('href', href); // link.setAttribute('download', downloadName);

    link.download = downloadName;
    document.body.appendChild(link);
    link.click();
    document.body.removeChild(link);
    props.onComplete();
  };

  React.useEffect(function () {
    if (!!props.stopSignal) {
      xhr.abort();
      setProgress(0);
      setMsg('');
    }
  }, [props.stopSignal]);
  return React__default.createElement("div", null, React__default.createElement("div", {
    className: "tn-download-msg ellipsis"
  }, msg), React__default.createElement("div", {
    className: "progress-bar"
  }, React__default.createElement(antd.Progress, {
    percent: progress,
    status: "active"
  })));
}

var useDownloadService = function useDownloadService() {
  var _useState = React.useState(null),
      files = _useState[0],
      setFiles = _useState[1];

  var _useState2 = React.useState(false),
      visible = _useState2[0],
      setVisible = _useState2[1];

  var _useState3 = React.useState(),
      onCloseCallbackFn = _useState3[0],
      setOnCloseCallbackFn = _useState3[1];

  var startDownload = React.useCallback(function (dfile, onCloseCallbackFn) {
    setFiles([].concat(dfile));
    setOnCloseCallbackFn(onCloseCallbackFn);
  }, []);
  var onEnd = React.useCallback(function () {
    setVisible(false);

    if (!!onCloseCallbackFn) {
      onCloseCallbackFn();
    }
  }, []);
  React.useEffect(function () {
    if (files != null) {
      setVisible(true);
    }
  }, [files]);
  return {
    files: files,
    visible: visible,
    startDownload: startDownload,
    onEnd: onEnd
  };
};
function DownloadPanel(props) {
  var _downloadContext$file2;

  var downloadContext = React.useContext(props.downloadContext);

  var _useState4 = React.useState(false),
      stopSignal = _useState4[0],
      setStopSignal = _useState4[1];

  var _useState5 = React.useState(0),
      uploadCounter = _useState5[0],
      setUploadCounter = _useState5[1];

  React.useEffect(function () {
    if (downloadContext.visible) {
      setStopSignal(false);
      var files = downloadContext.files;

      if (files == null || files.length === 0) {
        antd.message.warning('没有要下载的文件，下载被取消');
        onClose();
        return;
      }
    }
  }, [downloadContext.visible]);
  React.useEffect(function () {
    var _downloadContext$file;

    if (uploadCounter && uploadCounter === ((_downloadContext$file = downloadContext.files) == null ? void 0 : _downloadContext$file.length)) {
      onClose(500);
    }
  }, [uploadCounter]);

  var stop = function stop() {
    setStopSignal(true);
    onClose(0);
  };

  var onClose = function onClose(time) {
    if (time === void 0) {
      time = 1000;
    }

    setTimeout(function () {
      downloadContext.onEnd();
      setUploadCounter(0);
      setStopSignal(false);
    }, time);
  };

  return React__default.createElement(DragModal, {
    visible: downloadContext.visible,
    mask: true,
    showHeader: false,
    destroyOnClose: true,
    wrapClassName: "tn-download-panel-wrapper"
  }, React__default.createElement("div", {
    className: "tn-download-panel-container"
  }, (_downloadContext$file2 = downloadContext.files) == null ? void 0 : _downloadContext$file2.map(function (item, idx) {
    return React__default.createElement(DownloadItem, {
      downloadContext: props.downloadContext,
      getFileUrl: props.getFileUrl,
      file: item,
      key: idx,
      stopSignal: stopSignal,
      onComplete: function onComplete() {
        return setUploadCounter(function (pre) {
          return pre + 1;
        });
      }
    });
  }), React__default.createElement("div", {
    className: "footer"
  }, React__default.createElement(antd.Button, {
    danger: true,
    size: "small",
    onClick: stop
  }, "\u53D6\u6D88\u4E0B\u8F7D"))));
} //如果需要默认值可取消下面注释

DownloadPanel.defaultProps = {//     downloadContext: DownloadContext,
  //     getFileUrl: getFileUrl
};

function UploadButton(props) {
  //引入上下文
  var uploadFileContext = React.useContext(props.uploadFileContext); //上传文件后将文件储存至此

  var _useState = React.useState([]),
      uploadFileList = _useState[0],
      setUploadFileList = _useState[1]; //当上传文件列表发生改变时，调用上传文件api开始上传


  React.useEffect(function () {
    if (uploadFileList.length === 0) return;
    var files = uploadFileList.map(function (item) {
      return {
        file: item,
        callbackFn: props.uploadCallbackFn
      };
    });
    uploadFileContext.startUpload(files);
  }, [uploadFileList]); //在执行antd本身组件Upload的上传文件功能之前所做的事
  //这里需要禁止antd本身组件Upload的上传行为，因此必须返回false

  var beforeUpload = function beforeUpload(file, fileList) {
    if (uploadFileList.length === 0) {
      setUploadFileList([].concat(fileList));
    } else {
      if (file) {
        setUploadFileList([file]);
      }
    } //必须返回false，以阻止antd组件自身上传行为


    return false;
  };

  return React__default.createElement(antd.Upload, {
    name: "file",
    beforeUpload: beforeUpload,
    showUploadList: false
  }, React__default.createElement(antd.Button, {
    icon: React__default.createElement(icons.ArrowUpOutlined, null),
    title: props.title,
    size: "small",
    type: "dashed"
  }));
}
UploadButton.defaultProps = {
  title: "上传"
};

function UploadFilePanelItem(props) {
  var _useState = React.useState(0),
      progress = _useState[0],
      setProgress = _useState[1];

  var _useState2 = React.useState(0),
      localProgress = _useState2[0],
      setLocalProgress = _useState2[1];

  var _useState3 = React.useState(''),
      msg = _useState3[0],
      setMsg = _useState3[1];

  var xhr = new XMLHttpRequest();
  var reader = new FileReader();
  var file = props.file;
  React.useEffect(function () {
    startUpload();
  }, []);
  React.useEffect(function () {
    if (!!props.stopSignal) {
      xhr.abort();
      reader.abort();
    }
  }, [props.stopSignal]);

  var startUpload = function startUpload() {
    if (file == null) return;
    var filename = file.name;
    var suffix = filename.slice(filename == null ? void 0 : filename.lastIndexOf('.')) || '';
    var originName = filename.slice(0, filename == null ? void 0 : filename.lastIndexOf('.'));
    setMsg("\u6B63\u5728\u8BFB\u53D6\u672C\u5730\u6587\u4EF6 " + filename.slice(0, 50) + "...");
    var blobSlice = File.prototype.slice,
        chunkSize = 1024 * 1024 * 2,
        // Read in chunks of 2MB
    chunks = Math.ceil(file.size / chunkSize),
        currentChunk = 0,
        spark = new SparkMD5.ArrayBuffer();

    var loadNext = function loadNext() {
      var start = currentChunk * chunkSize,
          end = start + chunkSize >= file.size ? file.size : start + chunkSize;
      reader.readAsArrayBuffer(blobSlice.call(file, start, end));
    };

    reader.onprogress = function (e) {
      setLocalProgress(Math.round((e.loaded + currentChunk * chunkSize) / file.size * 100));
    };

    reader.onerror = function (e) {
      console.log(e.target.error);
      antd.message.error("\u6587\u4EF6 " + filename + " \u8BFB\u53D6\u5931\u8D25 (" + Math.round(file.size / 1024 / 1024) + "MB)", 3);
      setMsg("\u6587\u4EF6 " + filename.slice(0, 50) + "... \u8BFB\u53D6\u5931\u8D25 (" + file.size / 1024 / 2024 + "MB)");
      setLocalProgress(0);
      props.onComplete();
    };

    reader.onload = function (e) {
      spark.append(e.target.result); // Append array buffer

      currentChunk++;

      if (currentChunk < chunks) {
        loadNext();
        return;
      }

      var md5 = spark.end();
      var objectName = "" + md5 + (suffix || '');
      setLocalProgress(0);
      setMsg("\u5F00\u59CB\u4E0A\u4F20\u6587\u4EF6 " + filename + "...");
      var checkPromise = props.checkFileExists(md5); //通过md5值检查文件是否重复

      var getObjectUploadUrlPromise = props.getUploadUrl(objectName);
      axios.all([checkPromise, getObjectUploadUrlPromise]).then(function (_ref) {
        var res1 = _ref[0],
            res2 = _ref[1];
        var fileExists = res1.data;
        var url = res2.data;
        var uploadFile = {
          md5: md5,
          suffix: suffix,
          filePath: objectName,
          name: originName,
          fileSize: file.size
        };

        if (!!fileExists) {
          // 文件已存在
          props.callbackFn(uploadFile).then(function (_) {
            var p = Math.round(100);
            setProgress(p);
            setMsg(filename + " \u4E0A\u4F20\u5B8C\u6210\uFF01");
            props.onComplete();
          });
        } else {
          xhr.open('PUT', url, true);

          xhr.onload = function () {
            if (xhr.status === 200) {
              // resolve(xhr.response)
              props.callbackFn(uploadFile).then(function (_) {
                setMsg(filename + " \u4E0A\u4F20\u5B8C\u6210\uFF01");
                props.onComplete();
              });
            } else {
              setMsg(filename + " \u4E0A\u4F20\u5B8C\u6210\uFF01");
              props.onComplete();
            }
          }; // xhr.send(new Blob([reader.result]))


          xhr.send(file);
        }
      });
    };

    loadNext();
  };

  xhr.upload.onprogress = function (e) {
    var p = Math.round(e.loaded / e.total * 100);
    setProgress(p);
  };

  return React__default.createElement("div", {
    className: "upload-item"
  }, React__default.createElement("div", {
    className: "upload-msg ellipsis"
  }, "" + msg + (localProgress ? localProgress + "%" : '')), React__default.createElement("div", {
    className: "progress-bar"
  }, React__default.createElement(antd.Progress, {
    percent: progress,
    status: "active"
  })));
}

var useUploadService = function useUploadService() {
  var _useState = React.useState([]),
      files = _useState[0],
      setFiles = _useState[1];

  var _useState2 = React.useState(false),
      visible = _useState2[0],
      setVisible = _useState2[1];

  var _useState3 = React.useState(0),
      count = _useState3[0],
      setCount = _useState3[1];

  var startUpload = React.useCallback(function (uploadFiles) {
    setCount(0);
    setFiles(uploadFiles);
  }, []);
  var onEnd = React.useCallback(function (value) {
    setCount(value);
    setVisible(false);
  }, []);
  React.useEffect(function () {
    if (files.length > 0) {
      setVisible(true);
    }
  }, [files]);
  return {
    files: files,
    visible: visible,
    startUpload: startUpload,
    onEnd: onEnd,
    count: count
  };
};
function UploadPanel(props) {
  var uploadContext = React.useContext(props.uploadContext);

  var _useState4 = React.useState([]),
      files = _useState4[0],
      setFiles = _useState4[1];

  var _useState5 = React.useState(0),
      uploadCounter = _useState5[0],
      setUploadCounter = _useState5[1];

  var _useState6 = React.useState(false),
      stopSignal = _useState6[0],
      setStopSignal = _useState6[1];

  React.useEffect(function () {
    if (uploadContext.visible) {
      setStopSignal(false);
      start();
    }
  }, [uploadContext.visible]);
  React.useEffect(function () {
    if (uploadCounter && uploadCounter === files.length) {
      onClose();
    }
  }, [uploadCounter]);

  var start = function start() {
    var files = uploadContext.files;

    if (files == null || files.length === 0) {
      antd.message.warning('没有要上传的文件，上传被取消');
      onClose();
      return;
    }

    setFiles([].concat(files));
  };

  var onClose = function onClose(time) {
    if (time === void 0) {
      time = 500;
    }

    setTimeout(function () {
      setFiles([]);
      uploadContext.onEnd(uploadCounter);
      setUploadCounter(0);
    }, time);
  };

  var stop = function stop() {
    setStopSignal(true);
    onClose(0);
  };

  return React__default.createElement(DragModal, {
    visible: uploadContext.visible,
    mask: true,
    showHeader: false,
    destroyOnClose: true,
    wrapClassName: 'tn-upload-panel-wrapper'
  }, React__default.createElement("div", {
    className: "tn-upload-panel-container"
  }, React__default.createElement("div", {
    className: 'scrollable'
  }, files.map(function (item) {
    return React__default.createElement(UploadFilePanelItem, {
      checkFileExists: props.checkFileExists,
      getUploadUrl: props.getUploadUrl,
      onComplete: function onComplete() {
        return setUploadCounter(function (pre) {
          return pre + 1;
        });
      },
      key: item.file.uid,
      file: item.file,
      stopSignal: stopSignal,
      callbackFn: item.callbackFn
    });
  })), React__default.createElement("div", {
    className: "footer"
  }, React__default.createElement(antd.Button, {
    danger: true,
    size: "small",
    onClick: stop
  }, "\u53D6\u6D88\u4E0A\u4F20"))));
} // 如果需要默认值取消下面注释
// UploadPanel.defaultProps = {
//     checkFileExists: checkFileExists,
//     getPresignedPutObjectUrl: getPresignedPutObjectUrl,
//     uploadContext: UploadFileContext
// }

function CustomLink(props) {
  var to = props.to;
  var children = props.children;
  var resolved = reactRouterDom.useResolvedPath(to);
  var match = reactRouterDom.useMatch({
    path: (resolved == null ? void 0 : resolved.pathname) + "/*"
  });
  React.useEffect(function () {
    if (props.active) {
      props.active(!!match);
    }
  }, [match]);
  return React__default.createElement(reactRouterDom.Link, {
    to: to,
    className: classNames({
      'active': !!match
    }) + " " + props.className,
    style: {
      color: !!match && props.themecolor ? props.themecolor : null
    }
  }, children);
}

function CustomDivider(props) {
  return React__default.createElement("div", {
    className: classNames({
      "tn-horizontal-divider": !props.vertical,
      "tn-vertical-divider": props.vertical
    })
  });
}

function CustomList(_ref) {
  var _ref$dataSource = _ref.dataSource,
      dataSource = _ref$dataSource === void 0 ? [] : _ref$dataSource,
      key = _ref.key,
      title = _ref.title;
  return React__default.createElement("div", {
    className: "item-list"
  }, dataSource.map(function (item) {
    return React__default.createElement("div", {
      className: "item",
      key: item[key]
    }, React__default.createElement("div", {
      className: "item-name"
    }, item[title]));
  }));
}

function SystemNavigation(props) {
  return React__default.createElement("div", {
    className: "system-navigation"
  }, props.logoSrc && React__default.createElement("div", {
    className: "logo"
  }, React__default.createElement("img", {
    src: props.logoSrc,
    alt: "logo"
  })), React__default.createElement("div", {
    className: "main"
  }, props.items && props.items.map(function (item) {
    var isActive = item.type === props.activeType;
    return React__default.createElement(antd.Tooltip, {
      title: item.name,
      key: item.type,
      placement: "right",
      mouseEnterDelay: 0,
      mouseLeaveDelay: 0
    }, React__default.createElement("div", {
      className: classNames({
        "left-tool-item": true,
        "active": isActive
      }),
      onClick: function onClick() {
        if (props.onClick) {
          props.onClick(item);
        }
      }
    }, React__default.createElement("div", null, isActive ? item.iconActive : item.icon), React__default.createElement("div", {
      className: 'indicator',
      style: {
        color: props.indicatorColor ? props.indicatorColor : '#eee'
      }
    }, React__default.createElement(icons.CaretDownOutlined, null))));
  }), React__default.createElement("span", {
    className: 'tn-g-fill-remaining-space'
  }), props.bottomItems && props.bottomItems.map(function (item) {
    var isActive = item.type === props.activeType;
    return React__default.createElement(antd.Tooltip, {
      title: item.name,
      key: item.type,
      placement: "right",
      mouseEnterDelay: 0,
      mouseLeaveDelay: 0
    }, React__default.createElement("div", {
      className: classNames({
        "left-tool-item": true,
        "active": isActive
      }),
      onClick: function onClick() {
        if (props.onClick) {
          props.onClick(item);
        }
      }
    }, React__default.createElement("div", null, isActive ? item.iconActive : item.icon), React__default.createElement("div", {
      className: 'indicator'
    }, React__default.createElement(icons.CaretDownOutlined, null))));
  })));
}

exports.CategoryEChart = CategoryEChart;
exports.ClosableTabs = ClosableTabs;
exports.ColorSelect = ColorSelect;
exports.CommonTabbar = CommonTabbar;
exports.ContextMenuFC = ContextMenuFC;
exports.ContextMenuModal = ContextMenuModal;
exports.ContextMenuWrapper = ContextMenuWrapper;
exports.CustomDivider = CustomDivider;
exports.CustomLink = CustomLink;
exports.CustomList = CustomList;
exports.DatePicker = DatePicker;
exports.DownloadButton = DownloadButton;
exports.DownloadPanel = DownloadPanel;
exports.DragModal = DragModal;
exports.DroppableWrapper = DroppableWrapper;
exports.EditableCell = EditableCell;
exports.EditableRow = EditableRow;
exports.ExportDataToXlsx = ExportDataToXlsx;
exports.ImportDataFromXlsx = ImportDataFromXlsx;
exports.MultiEChart = MultiEChart;
exports.MultiLineChart = MultiLineChart;
exports.MultiTagSelect = MultiTagSelect;
exports.PhotoPanel = PhotoPanel;
exports.StatsPanel = StatsPanel;
exports.SystemNavigation = SystemNavigation;
exports.TestDiv = TestDiv;
exports.UploadButton = UploadButton;
exports.UploadDragger = UploadDragger;
exports.UploadPanel = UploadPanel;
exports.VerticalResizer = VerticalResizer;
exports.useCommonTabbarService = useCommonTabbarService;
exports.useDownloadService = useDownloadService;
exports.useUploadService = useUploadService;
//# sourceMappingURL=tncet-common.cjs.development.js.map
