# 颜色空间说明

## (一)颜色空间说明

### 1.RGB颜色空间

定义三原色红(Red/R)、绿(Green/G)、蓝(Blue/B)。自然界中的任何色彩都可以用这三种色彩叠加而成。这样用三原色叠加成的颜色空间被称为RGB颜色空间。

在计算机中，R、G、B的取值为0~255中的256个整数。0表示没有该颜色的刺激量，255表示刺激量达到最大。RGB均为0表示没有颜色刺激，显示为黑色；全为255表示最大颜色刺激，表示为白色。

![rgb](pic/rgb.png)

<font color="#ff0000">RGB颜色空间用直角坐标系表示颜色</font>

此外，计算机中也可用0~1之间的小数或颜色字符串表示颜色。(0, 255, 0)、(0, 1, 0)、'#00FF00'在RGB颜色空间下均可表示绿色。

### 2.HSL颜色空间

HSL颜色空间即将RGB颜色空间中的点在柱坐标系中表示，H、S、L分别代表色相(Hue)、饱和度(Saturation)、亮度(Lightness),<font color="#ff0000">是一种用柱坐标系表示颜色的方式</font>

#### (1)色相

色相是色彩的基本属性，即平时所说的红色、黄色等。在计算机中一般用0~360°的角度表示，称为色相角。

色相角为0°、120°、240°时分别对应红绿蓝三种颜色。色相角位于它们之间的表示两者的混合，例如60°表示红色与绿色的等比例混合，即为黄色。

色相相当于柱坐标系中的角度

#### (2)饱和度

饱和度是色彩的纯度（鲜艳度），饱和度越高色彩越纯，当饱和度变低时，颜色会变灰。计算机中取值为[0, 1]。

饱和度相当于柱坐标系中的底面半径

#### (3)亮度

亮度即色彩明亮程度。计算机中取值为[0, 1]。

亮度相当于柱坐标系中的高度。

### 3.HSV(HSB)颜色空间

HSV颜色空间与HSB颜色空间具有相同含义。它们都与HSL类似。H的含义相同，S的含义也与HSL类似。HSL中L表示亮度，亮度越高表示“白的亮度越高”；HSV中的V(value)与HSV中的B(Brightness)代表明度（光的量），可以是任何颜色，不一定局限于HSL中的白色。

| 内容 | HSL | HSV |
| :--: | :--: | :--: |
|色相|与HSV一致|与HSL一致|
|亮/明度|亮度为0时总是黑色<br/>亮度为1时总是白色<br/>亮度为0.5时为对应纯色<br/>hsl:(0°, 1, 0.5) = rgb:#ff0000|明度为0时总是黑色<br/>明度为1时为对应纯色|
|饱和度|控制所选色相的纯度|控制所选色相的纯度|
|有效色空间|双锥形|单锥形|

有效色空间是能够有效表达颜色的空间，像连续一片全部表现为黑色与白色的空间就不能被称为有效色空间（例如HSL中亮度为0与1时总是表现为白色或黑色，就不算有效色空间；HSV中亮度为0的时候表现为黑色，也不算有效色空间）。在这样的定义下，HSL与HSV的有效色空间示意图如下：

**HSL有效色空间**

![hsl](pic/hsl.png)

**HSV有效色空间**

![hsv](pic/hsv.png)

## (二)颜色空间转化

### 1.RGB与HSL转化

#### (1)RGB转HSL

设RGB表示下的颜色为(r, g, b), r,g,b $\in$ [0, 1]。设min表示r、g、b中的最大值、min表示最小值，则有：

![rgb to hsl](pic/rgb2hsl_1.png)

上面转化过程中有几点需要注意：

1)当rgb相等时，即为灰色，表现为在柱坐标系上的z轴，因此，h与s均设置为0。

2)亮度l与饱和度s的值仅与最大颜色值与最小颜色值有关，与最大、最小颜色值是谁无关，与中间颜色值无关，中间颜色值只会影响色相。（rgb:(100, 170, 120)与(150，100， 170)拥有相同的s与l）

2)s关于l大于0.5与小于等于0.5的分段函数是关于0.5对称的。这意味着有些rgb能得到不同的亮度却依旧可能得到相同的饱和度（例如(56, 100, 100)和(156, 200, 200)的饱和度均为28.2%）

<br/>

#### (2)HSL转RGB

本质上是RGB转HSL的逆过程

1)当s=0，即颜色位于柱坐标系的z轴上,此时，色相角h无意义，rgb颜色模式为亮度不等的灰色，即r=g=b=l*255

2)当s $\neq$ 0时，判断l与 $\frac{1}{2}$ 的大小关系（前面说过，0.5对应纯色，大于小于0.5对应纯色基础上更亮\暗，所以需要做区分），并将色相角h转化至[0, 1]之间。

![hsl to rgb](pic/hsl2rgb_1.png)

前面提到过，在色相角h中，r、g、b三者之间间隔120度。因此，接下来我们需要对 $h_k$做加120度与减120度的处理（即加减 $\frac{1}{3}$），得到和rgb有关的三个值  $t_R, t_G, t_B$。此外，为了保障这三个值位于[0, 1]中，我们将大于1的数减1，小于0的数加1，直到位于[0, 1]中。

![hsl to rgb](pic/hsl2rgb_2.png)

最后根据之前计算的pq值依次得出RGB的值：

![hsl to rgb](pic/hsl2rgb_3.png)

### 2.RGB与HSV转化

#### (1)RGB转HSV

RGB转HSV的色相h与RGB转HSL一致。

饱和度S与明度V的计算方式与HSL有区别，由于HSV的明度从0到1表示从黑到对应纯色，因此，HSV的计算公式中不用对0.5进行分段。

![rgb to hsv](pic/rgb2hsv_1.png)

<br/>

#### (2)HSV转RGB

由于没有分段，HSV转RGB也比HSL转RGB简单一些。

![hsv to rgb](pic/hsv2rgb_1.png)

![hsv to rgb](pic/hsv2rgb_2.png)

<script type="text/javascript" src="http://cdn.mathjax.org/mathjax/latest/MathJax.js?config=TeX-AMS-MML_HTMLorMML"></script>
<script type="text/x-mathjax-config">
    MathJax.Hub.Config({ tex2jax: {inlineMath: [['$', '$']]}, messageStyle: "none" });
</script>
